function [nBn, reject] = bkr(x,y,alpha)
% implements the Blum-Kiefer-Rosenblatt independence test
% for bivariate sample. Uses Mudholkar-Wilding (1993) tabulation
% for 5% and 1% critical values for sample lengths between 5 and 10


    if alpha~=0.01 & alpha~=0.05
        error('bkr():alpha has to be 0.01 or 0.05')
    end
    
    if length(x)~=length(y)
        error('bkr():x and y has to be the same size');
    end

        n = length(x);

    if n>10
        error('length of x has to be between 5 and 10')
    end
          

    N1 = zeros(1,n);
    N2 = zeros(1,n);
    N3 = zeros(1,n);
    N4 = zeros(1,n);
    
    for i = 1:n
        N1(i)= sum( (x <= x(i)) & (y<=y(i)));
        N2(i)= sum( (x > x(i)) & (y<=y(i)));
        N3(i)= sum( (x <= x(i)) & (y > y(i)));
        N4(i)= sum( (x > x(i)) & (y > y(i)));
    end
    
    nBn = sum( (N1.*N4 - N2.*N3).^2) /n^4;
    
    if alpha == 0.05
        if n==5 
            reject=(nBn>=0.0976);
        elseif n==6
            reject=(nBn>=0.0872);
        elseif n==7
            reject=(nBn>=0.0875);
        elseif n==8
            reject=(nBn>=0.0842);
        elseif n==9
            reject=(nBn>=0.0820);
        elseif n==10
            reject=(nBn>=0.0802);
        end
    elseif alpha== 0.01
        if n==5 
            reject=(nBn>=0.1408);
        elseif n==6
            reject=(nBn>=0.1435);
        elseif n==7
            reject=(nBn>=0.1312);
        elseif n==8
            reject=(nBn>=0.1274);
        elseif n==9
            reject=(nBn>=0.1250);
        elseif n==10
            reject=(nBn>=0.1218);
        end
    end

    