function [invbidboot,drawnbidders] = bootsample(invbidfunc,bids_data,infoset)

global aucgroupsize bidstepscum estim Group1 Group2 nbidfun oversample

%In each auctiongroup (for 3 months t bills), we should have 18*4=72 bids by submitters, and
%37*4=148 bids by other bidders. Let's count the nonzero bids we observe
%for each group, then we will assign "zero" bids so that the total number
%of bids in the data is indeed 55*4 (we need to include zero bids for
%resampling)participants
invbidboot=zeros(aucgroupsize*(size(Group1,2)+size(Group2,2)),nbidfun(1,2)); %This will include the zero bids.

auctions=1;
participants=[0 0 0]; %1st col: AuctionID, 2nd submitters, 3rd other bidders
partid=zeros(116,max(estim(:,4))); %entry equals 1 if participating in auction (rows auctions, col bidders)
span=ones(aucgroupsize,2);
for i=1:size(estim,1)
    if estim(max(i-1,1),2)~=estim(i,2), span(auctions,2)=i-1; auctions=auctions+1; span(auctions,1)=i; end
    partid(auctions,estim(i,4))=1;
end
span(aucgroupsize,2)=i;
for i=1:auctions
    submitters=0; otherbidders=0;
    for j=1:max(estim(:,4))        
        if partid(i,j)==1 && any(j==Group1)
            submitters=submitters+1;
        end
        if partid(i,j)==1 && any(j==Group2)
            otherbidders=otherbidders+1;
        end
    end        
    participants(i,:)=[span(i,1) submitters otherbidders];
end
% # of zero bids in current auctiongroup
submitterzero=aucgroupsize*size(Group1,2)-sum(participants(:,2));
otherbidderzero=aucgroupsize*size(Group2,2)-sum(participants(:,3));

    
%To try: bias bids towards non-zero ones:
%if matur==12, redfact=oversample; else redfact=1; end
if isempty(oversample)==1;
    redfact=1;
    redfactdealer=1;
else
    redfact=oversample;
    redfactdealer=max(oversample-0.2,1);
end

drawn_dealer=0;

drawnbidders=zeros(aucgroupsize*(size(Group1,2)+size(Group2,2)),3); % three columns: drawn customer bid, drawn dealer bid, =1 if dealer informed

%Need to draw whole pairs: draw customer bids first
for i=1:aucgroupsize*size(Group2,2) %Let's draw customers
    if rand>(otherbidderzero/(aucgroupsize*redfactdealer*size(Group2,2))) %Draw a nonzero bid
        drawnbidder=0; %To initiate the following loop
        while all(drawnbidder~=Group2) %keep drawing until a bid from this group
            k=ceil(rand*nbidfun(1,1));
            if any(estim(bidstepscum(k,1),4)==Group2)
                drawnbidder=estim(bidstepscum(k,1),4);
                invbidboot(aucgroupsize*size(Group1,2)+i,:)=invbidfunc(k,:);
                % Find the corresponding dealer bid: same auction, dealer bid (submitter=bidder), same dealer as submitter of customer bid, time closer to deadline than customer bid                
                dealer_bid=find(bids_data(:,1)==bids_data(k,1) & bids_data(:,2)==bids_data(:,3) & bids_data(:,3)==bids_data(k,2) & bids_data(:,5)<bids_data(k,5),1,'first');
                drawn_dealer=drawn_dealer+1;
                if isempty(dealer_bid)==0                    
                    invbidboot(drawn_dealer,:)=invbidfunc(dealer_bid,:);
                    drawnbidders(aucgroupsize*size(Group1,2)+i,:)=[k dealer_bid 1]; % this records info for the drawn customer bid
                    drawnbidders(drawn_dealer,:)=[k dealer_bid 1]; % this records info for the drawn dealer bid
                else % in this case no subsequent dealer bid => draw from uninformed dealers
                    temp=find(bids_data(:,2)==bids_data(:,3) & infoset(:,1)==0);
                    k2=ceil(rand*size(temp,1));
                    invbidboot(drawn_dealer,:)=invbidfunc(temp(k2),:);
                    drawnbidders(aucgroupsize*size(Group1,2)+i,:)=[k temp(k2) 0]; % this records info for the drawn customer bid
                    drawnbidders(drawn_dealer,:)=[k temp(k2) 0]; % this records info for the drawn dealer bid
                end                                    
            end
        end
    else
        drawnbidders(i,:)=[0 0 0];
    end
end

temp=find(bids_data(:,2)==bids_data(:,3) & infoset(:,1)==0);
%Draw remaining dealers' bids from uninformed dealers
for i=drawn_dealer+1:aucgroupsize*size(Group1,2) % drawn_dealer bids have been already drawn
    if rand>(submitterzero/(aucgroupsize*redfactdealer*size(Group1,2))) %Draw a nonzero bid
        drawnbidder=0; %To initiate the following loop
        while all(drawnbidder~=Group1) %keep drawing until a bid from this group
            k=ceil(rand*size(temp,1));
            if any(estim(bidstepscum(temp(k),1),4)==Group1)
                drawnbidder=estim(bidstepscum(temp(k),1),4);
                invbidboot(i,:)=invbidfunc(temp(k),:);
            end
        end
        drawnbidders(i,:)=[0 temp(k) 0];
    else
        drawnbidders(i,:)=[0 0 0];
    end
end
