function []=cvtest_boot(b1,b2,b3,b4,b5,b6,b7,b8,b9,b10)

% This is the main file for testing for common values in t-bill auctions. 
% b1 is # of bootstrap draws
% b2 is # of resampling draws
% b3 is which model to use. 1= v is continuous in q; 2= v is a step function
%   with steps ending at submitted quantities; 3= cnts in q for k<K and
%   price optimality condition for last step
% b4 what maturities to run the test on (currently possible only 12 or 3)
% b5 =1 if send email when job done which contains ip address of computer
%   where job was executed.
% b6 oversampling parameter for positive bids of customers (=1 if no
%   oversampling)
% b7 supply noise parameter (0 if no, otherwise variance of a random supply
%   shock)
% b8 # of auctions used to resample from in one group (aucgroupsize)
% b9 =1 if using kernel smoothed estimate of the mkt clearing price distribution
% b10 bandwidth in the uniform kernel used in resampling ("closeness" of
%   customer bids - should be in units of price: approx 25 = 1 basis point in
%   terms of 3-m yield)

%clear;
starttime=now;
global aucgroupsize auctions model pgrid pstep resamplingdraws bidstepscum bidsteps estim bootdraws Group1 Group2 Group3 nbidfun invbidboot boc_bids matur oversample supplynoise
%cd /tmp/jkastl
if nargin<10
    bandw=100;
else
    bandw=b10;
end
if nargin<9
    usekernel=1; % if to use smoothed price distribution (default YES)
else
    usekernel=b9;
end
if nargin<8
    aucgroupsize=4; %how many auctions to pool together for resampling
else
    aucgroupsize=b8;
end
if nargin<7
    supplynoise=0; % variance: if small random noise to supply should be added (improves precision)
else
    supplynoise=b7;
end
if nargin<6
    oversample=1;
else
    oversample=b6;
end
if nargin<5
    sendemail=0;
else
    sendemail=b5;
end
if nargin<4
    matur=3;
else
    matur=b4;
end
if nargin<3
    model=2;
else
    model=b3;
end
if nargin<2
    resamplingdraws=5000;
else
    resamplingdraws=b2;
end
if nargin<1
    bootdraws=1;
else
    bootdraws=b1;
end

derivnefix=0.0005; % perturbation parameter for derivative estimation - only needed for test under the alternative

timetemp=rem(now,1);
rand('twister',sum(100*clock));
randstate=rand('twister');

disp(['Testing for common values using t-bills with ' int2str(matur) ' months maturity'])
disp(['Will use ' int2str(resamplingdraws) ' resamples when getting clearing price distribution'])
disp(['In total we want ' int2str(bootdraws) ' bootstrap draws for std errors.'])  
disp(['Pooling ' int2str(aucgroupsize) ' auctions together for resampling.'])  
if usekernel==1
    disp(['Using smoothed p^c distribution.']) 
else
    disp(['Using UNsmoothed p^c distribution.']) 
end
clear b1 b2 b3 b4 b5 b6 b7 b8 b9 b10
savefile = ['canada_test_' int2str(matur) 'm_' int2str(bootdraws) '_auc' int2str(aucgroupsize) '_' int2str(resamplingdraws) '_' num2str(oversample) '_pkernel' num2str(usekernel) '_' num2str(bandw) '.mat'];

auctions=116;
pstep=5; %Parameter for the size of the step in the price grid
%trimcutoff=1250; % parameter for trimming when testing: 1250 price units = 50 basis points.
%testlevel=0.95;

%Initialize some variables           
teststat=mat2cell(zeros(1,bootdraws),1,ones(1,bootdraws));
flagmonotonicity=mat2cell(zeros(1,bootdraws),1,ones(1,bootdraws));
testsameq=mat2cell(zeros(1,bootdraws),1,ones(1,bootdraws));
flagsameq=mat2cell(zeros(1,bootdraws),1,ones(1,bootdraws));
sameq=mat2cell(zeros(1,bootdraws),1,ones(1,bootdraws));
margvalall=mat2cell(zeros(floor(auctions/aucgroupsize),bootdraws),ones(floor(auctions/aucgroupsize),1),ones(1,bootdraws));
derbkeq=mat2cell(zeros(floor(auctions/aucgroupsize),bootdraws),ones(floor(auctions/aucgroupsize),1),ones(1,bootdraws));
derbkstrict=mat2cell(zeros(floor(auctions/aucgroupsize),bootdraws),ones(floor(auctions/aucgroupsize),1),ones(1,bootdraws));
probbkstrict=mat2cell(zeros(floor(auctions/aucgroupsize),bootdraws),ones(floor(auctions/aucgroupsize),1),ones(1,bootdraws));
probbkweak=mat2cell(zeros(floor(auctions/aucgroupsize),bootdraws),ones(floor(auctions/aucgroupsize),1),ones(1,bootdraws));
%N=55; %Number of potential bidders within an auction - this could be a problem...55 identities, yet on avg only 18 participate
%It will be dealt with in the resampling subroutine.

valueofinfomax=[];
valueofinfomin=[];
valueofinfomax_expost=[ ]; % value of info using ex post prices and two different marginal valu estimates (upper env)
valueofinfomin_expost=[ ]; % value of info using ex post prices and two different marginal valu estimates (lower env)
valueofinfomax_expost_fu=[ ]; % value of info using ex post prices and updated marginal valu estimates (upper env)
valueofinfomin_expost_fu=[ ]; % value of info using ex post prices and updated marginal valu estimates (lower env)
valueofinfo_as_share=[ ]; % as a share of valueofinfomax_expost_fu
utmin=[ ];
utmax=[ ];
utmin_per_t=[ ];
utmax_per_t=[ ];
fixutmax= [ ];
fixutmin=[ ];
fixutmax_per_t=[ ];
fixutmin_per_t=[ ];
meanp_inf=[];
meanp_uninf=[];
stddevp_inf=[];
stddevp_uninf=[];


for auctiongroup=1:floor(auctions/aucgroupsize) %we have 116 auctions - which gives 29 auctiongroups of 4 auctions each. Use auctiongroup=0 if all auctions should be used
  disp(['working on: ---------auctiongroup:   '  num2str(auctiongroup)]) % ' & ' num2str(boot) ])
 %read the data
 if auctiongroup~=0 %read just subset of auctions
    [estim,noncomp,bidsteps,bidstepscum,pgrid,invbidfunc,span,spannonc,updated,infoset,relevinvbid]=dataread(auctiongroup,pstep); %Parameter=which group of the four auctions to read and size of step on price grid
    nbidfun=size(invbidfunc);
    %To plot a sample of an updated bid in auctiongroup 1: (in case only
    %one 'bootdraw')
    if auctiongroup==1 && bootdraws==1
        figure(1)
        if pstep==1
            plot(invbidfunc(relevinvbid(3,1),83*5:120*5),pgrid(1,83*5:120*5),'-',invbidfunc(relevinvbid(3,2),83*5:120*5),pgrid(1,83*5:120*5),'-',invbidfunc(relevinvbid(3,1)+1,83*5:120*5),pgrid(1,83*5:120*5),'-')
        end
        if pstep==5
            plot(invbidfunc(relevinvbid(3,1),83:120),pgrid(1,83:120),'-',invbidfunc(relevinvbid(3,2),83:120),pgrid(1,83:120),'-',invbidfunc(relevinvbid(3,1)+1,83:120),pgrid(1,83:120),'-')
        end
        legend('Original dealer bid','Updated dealer bid','Customer bid')
        xlabel('Quantity Share demanded')
        ylabel('Price (Bid)')
        title('Updating of Bids')
    end

 else %read all at once - this is for getting summary statistics mainly, not for actual estimation
     auctiongroup=1; 
     [estim_all,noncomp_all,bidsteps_all,bidstepscum_all,pgrid_all,invbidfunc_all,span,spannonc,updated_all,infoset_all,relevinvbid_all]=dataread(0,pstep);
     nbidfun=size(invbidfunc_all);
 end

if relevinvbid(1,1)>0 %at least one informed bidder in this auctiongroup
for boot=1:bootdraws %this is used for bootstrapping std errors 
        
  %Create a "bootstrap sample" of 'invbidfunc'
    if boot==1
        invbidboot=invbidfunc; %First bootstrap sample is the original sample
        bids_data=[]; %this variable needs to be re-computed since new "estim" data has been read. It is done in resampling_kernel
        drawnbidders=[]; % see comment above, will be done for each bootsample for boot>1
    else
        [invbidboot, drawnbidders]=bootsample(invbidfunc,bids_data, infoset); %Create bootstrap sample for this auctiongroup
    end

%Initialize variables
margvalall{auctiongroup,boot}=zeros(2*size(relevinvbid,1),max(bidsteps(:,1)));  
derbkeq{auctiongroup,boot}=zeros(2*size(relevinvbid,1),max(bidsteps(:,1)));
derbkstrict{auctiongroup,boot}=zeros(2*size(relevinvbid,1),max(bidsteps(:,1)));
probbkstrict{auctiongroup,boot}=zeros(2*size(relevinvbid,1),max(bidsteps(:,1)));
probbkweak{auctiongroup,boot}=zeros(2*size(relevinvbid,1),max(bidsteps(:,1)));

[ressupuninf, firstcust, bids_data, agdemuninf]=resampling_kernel(noncomp,boot,infoset,bandw, bids_data, drawnbidders); %Uninformed dealer

    for biddertemp=1:2*size(relevinvbid,1)  %Only estimate marg values for bidders who update 
                                            %(stored in 'relevinvbid' - always two consecutive entries: 
                                            %before and after updating)   
        if mod(biddertemp,2)==0 % This is the updated bid --> have to resample carefully
            bidder=relevinvbid(biddertemp/2,2);           
            [ressupinf, agdeminf]=resample_informed(ressupuninf,firstcust,infoset,bidder,agdemuninf);            
            if usekernel==1
                [psort,pdistr,range,meanp,stddevp]=pricedist_kernel(bidder,invbidfunc,ressupinf,agdeminf);
                if boot==1
                    meanp_inf=[meanp_inf; meanp];
                    stddevp_inf=[stddevp_inf; stddevp];
                end  
            else
                [psort]=pricedist(bidder,invbidfunc,ressupinf,agdeminf); % takes ORIGINAL bid from invbidfunc and uses the bootstrapped residual supplies
            end                     
        else % This is uninformed bidder, we can use resampled residual supplies from before
            bidder=relevinvbid((biddertemp+1)/2,1);
            if usekernel==1
                [psort,pdistr,range,meanp,stddevp]=pricedist_kernel(bidder,invbidfunc,ressupuninf,agdemuninf);
                if boot==1
                    meanp_uninf=[meanp_uninf; meanp];
                    stddevp_uninf=[stddevp_uninf; stddevp];
                end        
            else
                [psort]=pricedist(bidder,invbidfunc,ressupuninf,agdemuninf);
            end               
        end
        
        % estimate the impact of perturbing bidder's bid on the
        % distribution of mkt clearing price: this is needed for the
        % test of the restriction under the alternative: if this would be
        % large, the additional term in the test would be problematic
        if exist('derivnefix','var')==0
            derivnefix=0.0025; % perturbation parameter for derivative estimation
        end
        if mod(biddertemp,2)==0 % This is the updated bid            
            [derbkeq{auctiongroup,boot}(biddertemp,:),derbkstrict{auctiongroup,boot}(biddertemp,:),probbkstrict{auctiongroup,boot}(biddertemp,:),probbkweak{auctiongroup,boot}(biddertemp,:)]=der_pdist(bidder,bidsteps,invbidfunc,ressupinf,agdeminf,derivnefix);
        else
            [derbkeq{auctiongroup,boot}(biddertemp,:),derbkstrict{auctiongroup,boot}(biddertemp,:),probbkstrict{auctiongroup,boot}(biddertemp,:),probbkweak{auctiongroup,boot}(biddertemp,:)]=der_pdist(bidder,bidsteps,invbidfunc,ressupuninf,agdemuninf,derivnefix);
        end
        
        %discriminatory auction (need m-function margdiscr)
        if usekernel==1
           [margvalall{auctiongroup,boot}(biddertemp,:)]=margdiscr_kernel(bidder,psort,bidsteps,pdistr,range);
        else
           [margvalall{auctiongroup,boot}(biddertemp,:)]=margdiscr(bidder,psort,bidsteps);
        end

           %For robustness checks: use this part to impose nonincreasing marginal values by brute force 
           %if step<bidsteps{1,auctiongroup}(bidder,1)
           %    if margvalall{auctiongroup,boot}(bidder,step+1)>margvalall{auctiongroup,boot}(bidder,step)
           %      margvalall{auctiongroup,boot}(bidder,step+1)=margvalall{auctiongroup,boot}(bidder,step); %This uses the previous value as upper bound
           %    end
           %end

        %end

    %%%%%%%%%%%%%%%      Value of Information       %%%%%%%%%%%%%%%%%%%%%%%

        %Get the expected utility before and after updating given the estimates
        %and actual bids
        [exputmin{auctiongroup,boot}(biddertemp,1),exputmax{auctiongroup,boot}(biddertemp,1)]=exputil_da(bidder,margvalall{auctiongroup,boot}(biddertemp,:),psort,bidsteps,bidstepscum,estim);  

        if mod(biddertemp,2)==0 && boot==1 % get difference in expected utilities for the actual sample
            valueofinfomax=[valueofinfomax; exputmax{auctiongroup,boot}(biddertemp,1)-exputmax{auctiongroup,boot}(biddertemp-1,1) ];
            valueofinfomin=[valueofinfomin; exputmin{auctiongroup,boot}(biddertemp,1)-exputmin{auctiongroup,boot}(biddertemp-1,1) ];
        end

        %Get the ex post utility given the actual mkt clearing price and the
        %estimated marginal values before and after updating

        if mod(biddertemp,2)==0 && boot==1 % get difference in utilities for the actual sample
            clearpriceuninf=actualressup(relevinvbid(biddertemp/2,1),noncomp);
            clearpriceinf=actualressup(bidder,noncomp);
            [utmin_per_t(end+1),utmax_per_t(end+1),utmax(end+1),utmin(end+1)]=util(relevinvbid(biddertemp/2,1),margvalall{auctiongroup,boot}(biddertemp-1,:),clearpriceuninf);
            [utmin_per_t(end+1),utmax_per_t(end+1),utmax(end+1),utmin(end+1)]=util(bidder,margvalall{auctiongroup,boot}(biddertemp,:),clearpriceinf);
            valueofinfomax_expost(end+1)=utmax_per_t(end)-utmax_per_t(end-1);
            valueofinfomin_expost(end+1)=utmin_per_t(end)-utmin_per_t(end-1);
            %valueofinfomin_expost_se{1,boot}=valueofinfomin_expost; %collect value of info for std errors:
        end


        %Get the ex post utility given the estimated marginal values after
        %updating and original bid and updated bid
        if mod(biddertemp,2)==0  % get difference in utilities for the actual sample           
            [fixutmin_per_t(end+1),fixutmax_per_t(end+1),fixutmax(end+1),fixutmin(end+1)]=util(relevinvbid(biddertemp/2,1),margvalall{auctiongroup,boot}(biddertemp,:),clearpriceuninf);
            [fixutmin_per_t(end+1),fixutmax_per_t(end+1),fixutmax(end+1),fixutmin(end+1)]=util(bidder,margvalall{auctiongroup,boot}(biddertemp,:),clearpriceinf);        
            valueofinfomax_expost_fu(end+1)=fixutmax_per_t(end)-fixutmax_per_t(end-1);
            valueofinfomin_expost_fu(end+1)=fixutmin_per_t(end)-fixutmin_per_t(end-1);        
            valueofinfo_as_share(end+1)=valueofinfomax_expost_fu(end)/fixutmax_per_t(end);
            %valueofinfomax_expost_fu_se{1,boot}=valueofinfomax_expost_fu; %%collect value of info for std errors:
        end




    %%%%%%%%%%%%%%%      Construct test statistic   %%%%%%%%%%%%%%%%%%%%%%%

    %1st order margvalall by quantity demanded at that step
    if mod(biddertemp,2)==0        
        bidder0=relevinvbid(biddertemp/2,1);
        obsval=bidsteps(bidder0,1)+bidsteps(bidder,1);
        test0=zeros(obsval,2); % 1st column: marginal values, 2nd: quantities
        test0(1:bidsteps(bidder0,1),1)=(margvalall{auctiongroup,boot}(biddertemp-1,1:bidsteps(bidder0,1)))';
        test0(bidsteps(bidder0,1)+1:obsval,1)=(margvalall{auctiongroup,boot}(biddertemp,1:bidsteps(bidder,1)))';
        for step=1:bidsteps(bidder0,1)
            if bidder0>1
                test0(step,2)=estim(bidstepscum(bidder0-1,1)+step,7);
            else
                test0(step,2)=estim(step,7);
            end
        end
        for step=1:bidsteps(bidder,1)
            if bidder>1
                test0(bidsteps(bidder0,1)+step,2)=estim(bidstepscum(bidder-1,1)+step,7);
            else
                test0(bidsteps(bidder0,1)+step,2)=estim(step,7);
            end
        end
        test=sortrows(test0,2);    
        teststat{1,boot}(end+1,1)=0;
        flagmonotonicity{1,boot}(end+1,1:3)=[0 0 0];
        %flagmonotonicity{1,boot}(end+1,1:2)=[0 0];

        for step=2:obsval      
            %%%Now save the actual test statistic for non-monotonocity of marg
            %%%values
            if test(step,1)-test(step-1,1)>teststat{1,boot}(end,1)           %If positive, increasing marg value! and Pick the highest difference for each bidder only            
                %create a vector with flags when test statistic is big -
                %include the higher marginal value in 2nd column - this will be
                %used for trimming
                % Now save the monotonicity violation if it is bigger than the
                % largest saved for this bidder
                teststat{1,boot}(end,1)=test(step,1)-test(step-1,1);                    
                if teststat{1,boot}(end,1)>1250 % if bigger than 50 basis points, flag it
                    %and save the marginal value causing the monotonicity
                    %violation
                    flagmonotonicity{1,boot}(end,1:3)=[1 test(step-1,1) test(step,1)];
                else
                    flagmonotonicity{1,boot}(end,1:3)=[0 test(step-1,1) test(step,1)];                    
                end
                %if teststat{1,boot}(end,1)>10000 %Print big violations on screen
                %    disp(['Bootdraw: ' num2str(boot) ' Bidders ' num2str(bidder0) ' and ' num2str(bidder ) ' Auctiongroup ' num2str(auctiongroup) ' testval: ' num2str(teststat{1,boot}(end,1))])                
                %end

            end
           %Do same test on bidders who submit bids at the same quantity
            if test(step,2)==test(step-1,2)
               testsameq{1,boot}(end+1,1:3)=[bidder0,bidder, abs(test(step-1,1)-test(step,1))];
               if abs(test(step-1,1)-test(step,1))>1250 % if bigger than 50 basis points, flag it
                   flagsameq{1,boot}(end+1,1:3)=[1 test(step-1,1) test(step,1)];
               else
                   flagsameq{1,boot}(end+1,1:3)=[0 test(step-1,1) test(step,1)];
               end
            end

        end    
    end
    end %biddertemp finishes
if sendemail==1 % make sure file timestamp gets updated once in 24 hours
    if timetemp>rem(now,1) && timetemp-rem(now,1)<0.1
        ! touch /tmp/jkastl/*.*
        ! touch /tmp/jkastl
        timetemp=rem(now,1);
    end
end
clear ressupuninf ressupinf
end %boot finishes
end %if - loop finishes (for informed bidders)

if auctiongroup==floor(auctions/(2*aucgroupsize)) || auctiongroup==floor(auctions/aucgroupsize)
    currenttime=now;
    %savefile2=['canada_model_M' int2str(model) '_' int2str(matur) 'm_auc' int2str(aucgroupsize) '_gr' int2str(auctiongroup) '_O' num2str(oversample) '_S' num2str(supplynoise) '_pkernel' num2str(usekernel) '_' num2str(bandw) '.mat'];
    savefile2='pokus5.mat';
    save(savefile2)    
end

end %auctiongroup finishes

finishtime=now;
disp(datestr(starttime))
disp(datestr(finishtime))

%Evaluate the monotonicity test statistic and sort
if bootdraws>1 %Test has no meaning if only one draw
    [test,samplestat,critval]=cvtest_compute(teststat,0.05);


    %Check for NaN entries or Inf and eliminate those before computing
    %aggregates of test statistics and critical values
    b=isfinite(samplestat+critval);
    j=1;
    for i=1:size(critval,1)
        if b(i,1)==1
            critvaladj(j,1)=critval(i,1);
            samplestatadj(j,1)=samplestat(i,1);
            testadj(j,1)=test(i,1);
            j=j+1;
        end
    end
    disp('MONOTONICITY TEST:')
    disp(['Eliminated ' num2str(size(critval,1)-size(critvaladj,1)) ' entries with Inf or NaN'])
    disp(['Mean sample stat: ' num2str(mean(samplestatadj))])
    disp(['Median sample stat: ' num2str(median(samplestatadj))])
    disp(['Mean re-centered crit value: ' num2str(mean(critvaladj))])
    disp(['Median re-centered crit value: ' num2str(median(critvaladj))])
    teststatall=[testadj samplestatadj critvaladj];
    teststatall=sortrows(teststatall,1);

    disp(['Monotonicity test rejects for ' num2str(size(find(teststatall(:,1)>0),1)*100/size(teststatall,1)) ' % of bidders'])
    
    % Order statistics test:
    for i=1:bootdraws
        testorderstat(i,1)=prctile(teststat{1,i},95);
    end
    b=isfinite(testorderstat);
    j=1;
    for i=1:size(testorderstat,1)
        if b(i,1)==1
            testorderstatadj(j,1)=testorderstat(i,1);            
            testorderstatadj(j,1)=testorderstat(i,1);
            j=j+1;
        end
    end
        
    %Evaluate the test statistic at same q and sort
    [testQ,samplestatQ,critvalQ]=cvtest_compute(testsameq,0.05);

    %Check for NaN entries or Inf and eliminate those before computing
    %aggregates of test statistics and critical values
    b=isfinite(samplestatQ+critvalQ);
    j=1;
    for i=1:size(critvalQ,1)
        if b(i,1)==1
            critvalQadj(j,1)=critvalQ(i,1);
            samplestatQadj(j,1)=samplestatQ(i,1);
            testQadj(j,1)=testQ(i,1);
            j=j+1;
        end
    end
    disp(['Eliminated ' num2str(size(critvalQ,1)-size(critvalQadj,1)) ' entries with Inf or NaN'])
    disp(['Mean sample stat: ' num2str(mean(samplestatQadj))])
    disp(['Median sample stat: ' num2str(median(samplestatQadj))])
    disp(['Mean re-centered crit value: ' num2str(mean(critvalQadj))])
    disp(['Median re-centered crit value: ' num2str(median(critvalQadj))])
    teststatallQ=[testQadj samplestatQadj critvalQadj];
    teststatallQ=sortrows(teststatallQ,1);

    disp(['Equality test (for same q) rejects for ' num2str(size(find(teststatallQ(:,1)>0),1)*100/size(teststatallQ,1)) ' % of bidders'])
end

disp(['%%%%%%%% VALUE OF INFORMATION %%%%%'])
%%% There are few outliers that can potentially bias the value of info numbers, this 
%%% will trim at mean +-25 basis points, but using 50 has
%%% virtually no impact
if matur==12 %trimming values of info above this cutoff due to being unreasonable (cutoff set at 25 bp)
    infocutoff=2500; 
else
    infocutoff=625;
end
disp(['Number of bootstrap observations trimmed: ' num2str(size(valueofinfomax_expost_fu,2)-sum(abs(valueofinfomax_expost_fu)<infocutoff))])
disp(['Out of: ' num2str(size(valueofinfomax_expost_fu,2))])
disp(['Trimmed mean ex post given fixed util: ' num2str(mean(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff & valueofinfomax_expost_fu~=0)))])
disp(['Std Dev in trimmed sample ex post given fixed util: ' num2str(std(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff)))])

%%% Expected utility:
% Check for NaN entries or Inf and eliminate those
    b=isfinite(fixutmax_per_t);
    j=1;
    for i=1:size(fixutmax_per_t,2)
        if b(1,i)==1
            fixutmax_per_t_adj(j,1)=fixutmax_per_t(1,i);            
            j=j+1;
        end
    end
disp(['Trimmed mean expected util: ' num2str(mean(fixutmax_per_t_adj(abs(fixutmax_per_t_adj)<infocutoff & fixutmax_per_t_adj>0)))])

disp(['Share of value of info to mean expected util: ' num2str(mean(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff))...
    /mean(fixutmax_per_t_adj(abs(fixutmax_per_t_adj)<infocutoff)))])


if bootdraws>1 %otherwise the test variables don't exist
save(savefile,'teststat','testsameq','finishtime','bootdraws','resamplingdraws','teststatall','teststatallQ'...
,'sameq','valueofinfomax_expost_fu','valueofinfomin_expost_fu','valueofinfomax_expost','valueofinfomin_expost',...
'valueofinfomax','valueofinfomin')

% Test of the restriction under the alternative (2nd parameter is
% similarity_cutoff: how close two dealer q-weigthed bids have to be under
% the original (uninformed) bid to deem them having the same private signal
% (25 is about 1/4 of a basis point for 12-m maturity, 5 is about 1/5 of a basis point in 3-m)

%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M1_3m_auc4_gr29_O1_S0_pkernel1_5000.mat')
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M3_3m_auc4_gr29_O1_S0_pkernel1_5000.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M3_3m_auc2_gr58_O1_S0_pkernel1_5000.mat')
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M1_3m_auc4_gr29_O1_S0_pkernel1_500.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M1_3m_auc2_gr58_O1_S0_pkernel1_500.mat')
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M1_3m_auc1_gr116_O1_S0_pkernel1_500.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M1_12m_auc1_gr116_O1_S0_pkernel1_5000.mat')
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M1_12m_auc4_gr29_O1_S0_pkernel1_5000.mat')
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M3_12m_auc4_gr29_O1_S0_pkernel1_5000.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M3_12m_auc2_gr58_O1_S0_pkernel1_5000.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M3_12m_auc1_gr116_O1_S0_pkernel1_5000.mat')
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M3_12m_auc4_gr29_O1_S0_pkernel1_500.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M3_12m_auc2_gr58_O1_S0_pkernel1_500.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M3_12m_auc1_gr116_O1_S0_pkernel1_500.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M1_12m_auc1_gr116_O1_S0_pkernel1_500.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M1_12m_auc2_gr58_O1_S0_pkernel1_500.mat') 
%load('/home/jakub/matlab_results/cvtest/kernel_aug_09/canada_model_M1_12m_auc4_gr29_O1_S0_pkernel1_500.mat') 

if matur==12
    [teststat_alt,teststat_alt_within,test_pairs,teststat_maxmin,samplestat,avgderatbk,avgderbelowbk,allders_avgs,allders]=restr_test(margvalall,25,derbkeq,derbkstrict,probbkstrict,probbkweak);
    [margvalall_adj]=margvaladjust(margvalall,982000,2500); % max observed bid is 979,930 in 12m
    [teststat_adj_alt,teststat_adj_alt_within,test_adj_pairs,teststat_maxmin_adj,samplestat_adj,avgderatbk_adj,avgderbelowbk_adj,allders_avgs_adj,allders_adj]=restr_test(margvalall_adj,25,derbkeq,derbkstrict,probbkstrict,probbkweak);
else
    [teststat_alt,teststat_alt_within,test_pairs,teststat_maxmin,samplestat,avgderatbk,avgderbelowbk,allders_avgs,allders]=restr_test(margvalall,10,derbkeq,derbkstrict,probbkstrict,probbkweak);
    [margvalall_adj]=margvaladjust(margvalall,997000,2500); % of course higher observed bid in 3m
    [teststat_adj_alt,teststat_adj_alt_within,test_adj_pairs,teststat_maxmin_adj,samplestat_adj,avgderatbk_adj,avgderbelowbk_adj,allders_avgs_adj,allders_adj]=restr_test(margvalall_adj,10,derbkeq,derbkstrict,probbkstrict,probbkweak);
end
save('derivatives3.mat','avgderatbk','avgderbelowbk','allders_avgs','allders','probbkstrict')
save(savefile2)
end


%Everything is done: send email with IP report.
if sendemail==1
    %Renew time stamps on file so that stanford unix servers do not delete them
    ! /tmp/jkastl/stampweek.sh
    ! ifconfig | grep 'inet addr' > /tmp/jkastl/ipreport.txt
    ! ps aux | grep MATLAB >> /tmp/jkastl/ipreport.txt
    ! cat /tmp/jkastl/ipreport.txt | mail -s 'Job done!' jkastl
end
