function[estim,noncomp,bidsteps,bidstepscum,pgrid,invbidfunc,span,spannonc,updated,infoset,relevinvbid]=dataread(auctiongroup,pstep)

%data.txt contains data on bids. 1st column is just ID generated in db
%program. 2nd col: auction_id, 3rd c: submitter, 4th c: tender_number, 5th
%c: yield bid, 6th: q-bid, 7th: actual bidder, 8th: time_to_deadline, 9th:
%preannounced supply, 10th: net position in when-issued market. Parameter 'Auctiongroup' denotes which group of 4
%auctions to return. if auctiongroup=0, use all data.

%These global variables are accessed in the 'resample.m' routine.
global boc_bids Group1 Group2 Group3 matur aucgroupsize

%load data.txt -ascii
%load noncomp.txt -ascii
if isempty(matur)
    data=csvread('data_3m.csv');
    noncomp=csvread('noncomp_3m.csv');
    matur=3;
else
    if matur==12
        data=csvread('data_12m.csv');
        noncomp=csvread('noncomp_12m.csv');
    else
        data=csvread('data_3m.csv');
        noncomp=csvread('noncomp_3m.csv');
    end
end

data=data(data(:,5)>0,:); %Take only entries with positive price bids
noncomp=noncomp(noncomp(:,5)>0,:); %Take only entries with quantity bids

%this routine figures out the groups of bidders in 'data'
if isempty(Group1)==1
    maxbidder=max(max(data(:,3)),max(data(:,7)));
    Group1=[];
    Group2=[];
    Group3=[]; %This guy is a customer who became a dealer. (bidder 88) - customer until auction 11, dealer until auction 33, then disappears
    for j=1:maxbidder
        if max(data(:,3)==j)==1
            Group1(1,end+1)=j; %Submitters - looks like there are 18 of these in both 3m and 12m
            if max(data(data(:,3)~=data(:,7),7)==j)==1
                Group3(1,end+1)=j;
            end
        else
            if max(data(:,7)==j)==1
                Group2(1,end+1)=j; %Customers: 37 of these in 3m, 51 in 12m
            end
        end
    end     
end  
    
    
data(:,5)=data(:,5)*10000; %convert prices...
datsize=size(data);
noncompsize=size(noncomp);
%Normalize q-demands at each step

data(:,datsize(1,2)+1)=data(:,6)./data(:,9);
noncomp(:,noncompsize(1,2)+1)=noncomp(:,5)./noncomp(:,8);

%Find noncompetitive bids of bank of canada:
if isempty(boc_bids)==1;
    boc_bids=noncomp(noncomp(:,3)==12,:);
end

%create span variable, which stores span of individual auctions in "data"
auctions=1;
span=[data(1,2) 1 0];
for i=2:datsize(1,1)
    %count unique auction IDs
    if data(i-1,2)~=data(i,2) %new auction        
        auctions=auctions+1;
        if auctions>1
            span(auctions,1)=data(i,2);
            span(auctions,2)=i; %beginning of an auction in estim
            span(auctions-1,3)=i-1; %end of an auction
        else
            span(auctions,1)=data(i-1,2);
            span(auctions,2)=1;
        end
    end
end    
%last auction:
span(auctions,:)=[data(i,2) span(auctions-1,3)+1 i];

%Same thing for noncompetitive bids
spannonc=[noncomp(1,2) 1 0];
aucnc=1;
for i=2:noncompsize(1,1)
    if noncomp(i-1,2)~=noncomp(i,2)
       aucnc=aucnc+1;
       if aucnc>1
            spannonc(aucnc,1)=noncomp(i,2);
            spannonc(aucnc,2)=i; %beginning of an auction in estim
            spannonc(aucnc-1,3)=i-1; %end of an auction
        else
            spannonc(aucnc,1)=noncomp(i-1,2);
            spannonc(aucnc,2)=1;
        end
    end
end     
spannonc(aucnc,:)=[noncomp(i,2) span(aucnc-1,3)+1 i];

%use variable auctiongroup to read the relevant bids, if auctiongroup=0,
%use all data
if auctiongroup~=0
    data=data(span(aucgroupsize*(auctiongroup-1)+1,2):span(aucgroupsize*auctiongroup,3),:);
    noncomp=noncomp(spannonc(aucgroupsize*(auctiongroup-1)+1,2):spannonc(aucgroupsize*auctiongroup,3),:);
end

datsize=size(data);

%Now construct corresponding inverse demands and cumulative demands

%count number of bidfunctions
nbidfuns=1;
data(1,datsize(1,2)+1)=data(1,datsize(1,2)); %the extra column stores cumulative demand
datsize=size(data);

for j=2:datsize(1,1)
   if data(j,7)==data(j-1,7)
       %['Same Bidder']
       if data(j,4)==data(j-1,4)
           %['Same Tender']
          data(j,datsize(1,2))=data(j,datsize(1,2)-1)+data(j-1,datsize(1,2));
       else
           %['Same bidder, new bid']
          nbidfuns=nbidfuns+1; 
          data(j,datsize(1,2))=data(j,datsize(1,2)-1); 
       end
   else 
       %['New bidder']
        nbidfuns=nbidfuns+1;
        data(j,datsize(1,2))=data(j,datsize(1,2)-1);
    end
end

        
  %create price grid in basis points
  
  pmin=min(data(:,5))-50;
  pmax=max(data(:,5))+50;
  
  pgrid=pmin:pstep:pmax;
  pgridsize=size(pgrid);
  
  invbidfunc=zeros(nbidfuns,pgridsize(1,2));
  
%set a reference variable referring to the line in data (bidpoint) and initiate a variable to which to store number of steps
    k=0;
    bidsteps=zeros(nbidfuns,1);
    
% Construct a variable which cummulatively sums the steps in bidfunctions - this will allow for easier addressing of prices 
% when estimating the derivative
    bidstepscum=zeros(nbidfuns,1);
    
for q=1:nbidfuns
    %counts line in data
    k=k+1;
    %counts steps in current bidfunction
    j=1;
        for m=pgridsize(1,2):-1:1
            %first check if the current point on grid is less or equal to p bid on current line k (i.e., higher yield than the bid), if yes then enter current cumulative quantity bid                        
            if data(k,5)>=pgrid(1,m), invbidfunc(q,m)=data(k,end); end
            
            if k<datsize(1,1)
   %if next bidpoint is still by same bidder, check whether it is higher than the next point on the grid, if yes take next one
                if data(k,2)==data(k+1,2) && data(k,7)==data(k+1,7) && data(k,4)==data(k+1,4), if data(k+1,5)>=pgrid(1,max(m-1,1)), k=k+1; j=j+1; end 
                    else
   %check if the next bidpoint is still by the same bidder, if not, break the for loop to get the next bidcurve
   
                    if m==1, bidsteps(q,1)=j; bidstepscum(q,1)=bidstepscum(max(1,q-1),1)+j; break, end
                end               
            else bidsteps(q,1)=j; bidstepscum(q,1)=bidstepscum(max(1,q-1),1)+j;
            end          
            
        end
end

estim(:,6)=data(:,6)./data(:,9); % marginal q-bid
estim(:,5)=data(:,5); %price bid
estim(:,7)=data(:,12); %cumul q-bid
estim(:,3)=data(:,9); %Q for sale
estim(:,2)=data(:,2); %auction ID
estim(:,4)=data(:,7); %Bidder
estim(:,8)=data(:,8); %Time to deadline
estim(:,1)=data(:,3); %submitter
estim(:,9)=data(:,10); %net position on 'when issued' market
estim(:,10:11)=zeros(size(estim,1),2);
% 10th column in estim: non-competitive bid submitted weakly before the bid
% at this line
% 11th column in estim: time to deadline of the non-competitive bid
% submission
for i=1:size(noncomp,1)
    temp=find(estim(:,2)==noncomp(i,2) & noncomp(i,3)==estim(:,4) & estim(:,8)<=noncomp(i,7));
    if isempty(temp)==0
        estim(temp,10:11)=[ones(size(temp,1),1)*noncomp(i,9) ones(size(temp,1),1)*noncomp(i,7)];    
    end
end
        
    
    


infoset=zeros(nbidfuns,55); %this variable stores for each bidder (row) 
%in the columns the bidfunctions (number of the line in invbidfunc) that
%corresponds to bid that the submitter observes before submitting his own
%let's find updated bids
bidf=1;
%info=1;
known=zeros(nbidfuns,1); %this vector stores how many bids a submitter knows
for i=1:datsize(1,1)-1
       if estim(i,4)==estim(max(i-1,1),4) && estim(i,8)==estim(max(i-1,1),8) %['Same Bidder and time to finish']
       %do nothing       
       else %['new bid']
          bidf=bidf+1; %this just tracks line in 'invbidfunc' in which this bidder's bid is stored.          
       end
    k=estim(i,1); %submitter
    if estim(i,4)~=k && estim(max(i-1,1),4)~=estim(i,4) %submitting a bid on someone's behalf, and we want to count that bid only once
        bidfsub=bidf;
        for j=1:40 %check next 40 entries in the data if followed by k'th bid in the same auction
             if i+j>datsize(1,1), break, end
             if estim(i+j,4)==estim(max(i+j-1,1),4) && estim(i+j,8)==estim(max(i+j-1,1),8) %['Same Bidder and time to finish']
                %do nothing       
             else %['new bid']
                bidfsub=bidfsub+1; %this tracks line in 'invbidfunc' in which submitter's bid is stored.          
             end           
             if estim(i,2)==estim(i+j,2) && estim(i+j,4)==k && estim(i+j,8)~=estim(i+j-1,8) %bid by k in the same auction                
                infoset(bidfsub,known(bidfsub,1)+1)=bidf; known(bidfsub,1)=known(bidfsub,1)+1;                              
             end
        end
    end                
end

updated=[0 0 0 0 0 0 0 0 0]; %updated bids - [auction, submitter, line in estim where new bid starts,...
                    %line in estim where the 'last' original bid ends, forward position new bid,...
                    %forward position 'last' bid, change in forward position, time-to
                    %deadline original bid, time-to-deadline updated bid]
n=1;
for i=1:datsize(1,1)-1
    k=estim(i,1); %submitter
    if estim(i+1,1)==k && estim(i,4)==k && estim(i+1,4)~=k %k'th bid followed suddenly by different bidder
        for j=1:20 %check next 20 entries in the data if again followed by k'th bid in the same auction
            if i+j>datsize(1,1), break, end
            if estim(i,2)==estim(i+j,2) && estim(i+j,4)==k && estim(i+j,8)~=estim(i,8) %updated bid by k in the same auction
                updated(n,:)=[estim(i,2) k i+j i estim(i+j,9) estim(i,9) estim(i+j,9)-estim(i,9) estim(i,8) estim(i+j,8)]; n=n+1;
                break
            end
        end
    end
end

relevinvbid=zeros(size(updated,1),2); %Relevant inverse bid functions for which values will be estimated
j=1;
for i=1:size(bidstepscum,1)
    if bidstepscum(i,1)==updated(j,4)
        relevinvbid(j,1)=i;
    end
    if bidstepscum(i,1)+1==updated(j,3)
        relevinvbid(j,2)=i+1;
        j=j+1;
    end
    if j>size(updated,1), break, end
end