function [derbkeq,derbkstrict,probintstrict,probintweak]=der_pdist(bidder,bidsteps,invbidfunc,ressup,agdem,derivnefix)

 % Function that calculates the derivative of Pr(p^c=b_k) and 
 % \partial Pr(b_k>p^c>b_k+1) wrt q_k, and also Pr(b_k>p^c>b_k+1) and Pr(b_k>=p^c>=b_k+1). At each step of the bid function, it perturbs the bid by the fixed
 % neighborhood to the left and then recalculates the distribution of the
 % market clearing price.
 
 % defivnefix is the fixed neighborhood by which bid should be perturbed to
 % the left

if exist('derivnefix', 'var')==0 
    derivnefix=0.0025; % default is quarter of a percent of the supply
end
 
global resamplingdraws pgrid estim bidstepscum pstep

pmin=min(pgrid(1,:));
pclear=zeros(resamplingdraws,3);
datasize=size(invbidfunc);
derbkeq=zeros(1,max(bidsteps(:,1)));
derbkstrict=zeros(1,max(bidsteps(:,1)));
probintstrict=zeros(1,max(bidsteps(:,1)));
probintweak=zeros(1,max(bidsteps(:,1)));

[psort]=pricedist(bidder,invbidfunc,ressup,agdem);
j=1;
while psort(j,1)==0, if j==size(psort,1), break, end, j=j+1; end %this eliminates simulated states in which market does not clear
psort=psort(j:end,:);
if bidder==1
    pstepmax=max(estim(1:bidsteps(bidder,1),5));
    pstepmin=min(estim(1:bidsteps(bidder,1),5));
else
    pstepmax=max(estim(bidstepscum(bidder-1,1)+1:bidstepscum(bidder-1,1)+bidsteps(bidder,1),5));
    pstepmin=min(estim(bidstepscum(bidder-1,1)+1:bidstepscum(bidder-1,1)+bidsteps(bidder,1),5));
end   
range_orig=min(floor(psort(:,1)/pstep)*pstep,pstepmin-pstep):pstep:max(ceil(psort(:,1)/pstep)*pstep,pstepmax+pstep); %range for support of smoothed density of market clearing price
[pdistr_orig]=ksdensity(psort(:,1),range_orig); %obtain non-parametric estimate of the distribution

%Start by determining the two prices between which the 'step' is, and then which point on the price grid these correspond to
for step=1:bidsteps(bidder,1)
    if bidder==1
        pstepmax=estim(step,5);
    else
        pstepmax=estim(bidstepscum(max(bidder-1,1))+step,5);
    end
    pstepmax=round(pstepmax/pstep)*pstep;
    if step==bidsteps(bidder,1) %make sure that the last step checks prices up to zero
        pstepmin=pmin; %Actually let it be the minimum price on the grid
    else
         if bidder==1
            pstepmin=estim(step+1,5);
         else
            pstepmin=estim(bidstepscum(max(bidder-1,1))+step+1,5);
         end
    end  
    pstepmin=round(pstepmin/pstep)*pstep;
    % perturb the demand at the current step
    pertinvbid=zeros(1,datasize(1,2)); %This will be the perturbed demand schedule
    for p=1:datasize(1,2)
        if (pgrid(1,p)<=pstepmax) && (pgrid(1,p)>=pstepmin)
            if step==1
                pertinvbid(1,p)=max(invbidfunc(bidder,p)-derivnefix,0); %perturb the demand at most to zero
            else
                if bidder==1
                    if invbidfunc(bidder,p)-derivnefix<estim(step-1,7); %don't perturb too much - to cross the next closest step
                        pertinvbid(1,p)=estim(step-1,7);
                    else
                        pertinvbid(1,p)=invbidfunc(bidder,p)-derivnefix;
                    end
                else
                    if invbidfunc(bidder,p)-derivnefix<estim(bidstepscum(bidder-1,1)+step-1,7);
                        pertinvbid(1,p)=estim(bidstepscum(bidder-1,1)+step-1,7);
                    else
                        pertinvbid(1,p)=invbidfunc(bidder,p)-derivnefix;
                    end
                end
            end
        else
            pertinvbid(1,p)=invbidfunc(bidder,p);
        end
    end
    invbid_pert=invbidfunc;
    invbid_pert(bidder,:)=pertinvbid;
    %[psort]=pricedist(bidder,invbidfunc,ressup,agdem); 
    range=min(floor(psort(:,1)/pstep)*pstep,pstepmin-pstep):pstep:max(ceil(psort(:,1)/pstep)*pstep,pstepmax+pstep); %range for support of smoothed density of market clearing price
    [pdistr]=ksdensity(psort(:,1),range); %obtain non-parametric estimate of the distribution
    
    [psortch]=pricedist(bidder,invbid_pert,ressup,agdem);
    j=1;
    while psortch(j,1)==0, if j==size(psortch,1), break, end, j=j+1; end %this eliminates simulated states in which market does not clear!
    psortch=psortch(j:end,:);
    rangech=min(floor(psortch(:,1)/pstep)*pstep,pstepmin-pstep):pstep:max(ceil(psortch(:,1)/pstep)*pstep,pstepmax+pstep); %range for support of smoothed density of market clearing price
    [pdistrch]=ksdensity(psortch(:,1),rangech); %obtain non-parametric estimate of the distribution
    %[pdistrch]=ksdensity(psortch(:,1),range); %obtain non-parametric estimate of the distribution
    temp1=find(range<=pstepmax,1,'last');
    temp2=find(range>=pstepmax,1,'first');
    if isempty(temp2)==0 && isempty(temp1)==0
        if temp1==temp2
            bk_ind_orig_der=temp1; % there is a price on the original grid equal to pstepmax
        else
            bk_ind_orig_der=[temp1 temp2]; % the two values on the grid around pstepmax
        end
    else
        bk_ind_orig_der=[];
    end
    temp1=find(range<=pstepmin,1,'last');
    temp2=find(range>=pstepmin,1,'first');
    if isempty(temp2)==0 && isempty(temp1)==0
        if temp1==temp2
            bk_next_ind_orig_der=temp1; % there is a price on the original grid equal to pstepmin
        else
            bk_next_ind_orig_der=[temp1 temp2]; % the two values on the grid around pstepmin
        end            
    else
        bk_next_ind_orig_der=[];
    end
    temp1=find(rangech<=pstepmax,1,'last');    
    temp2=find(rangech>=pstepmax,1,'first');
    if isempty(temp2)==0 && isempty(temp1)==0
        if temp1==temp2
            bk_ind_pert=temp1;
        else
            bk_ind_pert=[temp1 temp2];
        end
    else
        bk_ind_pert=[];
    end
    temp1=find(rangech<=pstepmin,1,'last');    
    temp2=find(rangech>=pstepmin,1,'first');
    if isempty(temp2)==0 && isempty(temp1)==0
        if temp1==temp2
            bk_next_ind_pert=temp1;
        else
            bk_next_ind_pert=[temp1 temp2];
        end
    else
        bk_next_ind_pert=[];
    end
    temp1=find(range_orig<=pstepmax,1,'last');
    temp2=find(range_orig>=pstepmax,1,'first');
    if isempty(temp2)==0 && isempty(temp1)==0
        if temp1==temp2
            bk_ind_orig=temp1; % there is a price on the original grid equal to pstepmax
        else
            bk_ind_orig=[temp1 temp2]; % the two values on the grid around pstepmax
        end
    else
        bk_ind_orig=[];
    end
    temp1=find(range_orig<=pstepmin,1,'last');
    temp2=find(range_orig>=pstepmin,1,'first');
    if isempty(temp2)==0 && isempty(temp1)==0
        if temp1==temp2
            bk_next_ind_orig=temp1; % there is a price on the original grid equal to pstepmin
        else
            bk_next_ind_orig=[temp1 temp2]; % the two values on the grid around pstepmin
        end
    else
        bk_next_ind_orig=[];
    end
    if isempty(bk_ind_orig) || isempty(bk_next_ind_orig)        
        if  range(1,end)<pstepmin  % price will be always lower than the bid
            derbkstrict(1,step)=0;
            derbkeq(1,step)=0;           
        else
            if range(1,end)<pstepmax
                derbkeq(1,step)=0;           
                derbkstrict(1,step)=(sum(pdistr(1,bk_ind_orig+1:bk_next_ind_orig-1))/size(bk_ind_orig,2)/sum(pdistr)-sum(pdistrch(1,bk_ind_pert+1:bk_next_ind_pert-1))/size(bk_ind_pert,2)/sum(pdistrch))/derivnefix;
            end
        end
    else
        derbkeq(1,step)=(sum(pdistr(1,bk_ind_orig_der))/size(bk_ind_orig_der,2)/sum(pdistr)-sum(pdistrch(1,bk_ind_pert))/size(bk_ind_pert,2)/sum(pdistrch))/derivnefix;
        derbkstrict(1,step)=(sum(pdistr(1,max(bk_next_ind_orig_der)+1:min(bk_ind_orig_der)-1))/sum(pdistr)-sum(pdistrch(1,max(bk_next_ind_pert)+1:min(bk_ind_pert)-1))/sum(pdistrch))/derivnefix;
        probintstrict(1,step)=sum(pdistr_orig(1,max(bk_next_ind_orig)+1:min(bk_ind_orig)-1))/sum(pdistr_orig);
        probintweak(1,step)=sum(pdistr_orig(1,min(bk_next_ind_orig):max(bk_ind_orig)))/sum(pdistr_orig);
    end
end