function[margval]=margdiscr(bidder,psort,bidsteps)

%This function returns vector of marginal values for this bidder in a
%discriminatory auction using the optimality equation for quantity
global pstep pgrid estim bidstepscum model

pmin=min(pgrid(1,:));
%pmax=max(pgrid(1,:));
shade=zeros(1,bidsteps(bidder,1)); %stores shading factor at each step 
margval=zeros(1,max(bidsteps(:,1))); %stores estimate of marginal valuation at submitted q
%probstrict=zeros(bidsteps(bidder),1); %will store the probability that price is strictly between the two steps
%probweak=zeros(bidsteps(bidder),1); %will store the probability that price is weakly below next step

%Let us smooth the density of market clearing prices:

%Support for the smoothed density:

j=1;
while psort(j,1)==0, if j==size(psort,1), break, end, j=j+1; end
psortpos=psort(j:end,:);
range=min(psortpos(:,1)):pstep:max(psortpos(:,1));
[pdistr]=ksdensity(psortpos(:,1),range);
%plot(pdistr)

%Start by determining the two prices between which the 'step' is, and then which point on the price grid these correspond to
for step=1:bidsteps(bidder,1)

    if bidder==1
        pstepmax=estim(step,5);
    else
        pstepmax=estim(bidstepscum(max(bidder-1,1))+step,5);
    end
    
    if step==bidsteps(bidder,1) %make sure that the last step checks prices up to zero
        pstepmin=pmin; %Actually let it be the minimum price on the grid
    else
         if bidder==1
            pstepmin=estim(step+1,5);
         else
            pstepmin=estim(bidstepscum(max(bidder-1,1))+step+1,5);
         end
    end  


    %Let's get the probability that p is strictly between the two steps and
    %weakly below next one
    i=0;
    x=size(range);
    while range(1,min(i+1,x(1,2)))<=pstepmin, if i==x(1,2), break, end, i=i+1; end
    j=i;
    while range(1,min(j+1,x(1,2)))<pstepmax, if j==x(1,2), break, end, j=j+1; end

    if range(1,min(j+1,x(1,2)))==pstepmax, k=j+1; else k=j; end
    if k==0, k=1; disp(['Only zero prices!' num2str(bidder)]), end %in case only zero prices were recorded 
    probwe=sum(pdistr(1,1:k)); %The denominator cancels out when getting shading factor H/H_{p}
    if j>0
        probst=sum(pdistr(1,max(i,1):j));
    else
        probst=0;
    end


    %"H/H_{p}"
    if model==1 %Model 1 is continuous marginal valuation, 2 is step function
        if step<bidsteps(bidder,1)  
            shade(1,step)=(pstepmax-pstepmin)*probwe/probst; 
        else        
            shade(1,step)=0;
        end
    else 
        shade(1,step)=(pstepmax-pstepmin)*probwe/probst; %This is a crude approximation at last step!
    end
    
%Marginal valuation estimate at the current quantity-step
margval(1,step)=pstepmax+shade(1,step);

end