function[margval]=margdiscr_kernel(bidder,psort,bidsteps,pdistr,range)

%This function returns vector of marginal values for this bidder in a
%discriminatory auction using the optimality equation for quantity
global pstep pgrid estim bidstepscum model

usesmooth=1; % this parameter=1 if using kernel smoothing of price distribution

pmin=min(pgrid(1,:));
%pmax=max(pgrid(1,:));
shade=zeros(1,bidsteps(bidder,1)); %stores shading factor at each step 
margval=zeros(1,max(bidsteps(:,1))); %stores estimate of marginal valuation at submitted q
%probstrict=zeros(bidsteps(bidder),1); %will store the probability that price is strictly between the two steps
%probweak=zeros(bidsteps(bidder),1); %will store the probability that price is weakly below next step

%Let us smooth the density of market clearing prices:

%Support for the smoothed density:
if exist('pdistr','var')==0
    j=1;
    while psort(j,1)==0, if j==size(psort,1), break, end, j=j+1; end %this eliminates simulated states in which market does not clear!
    psortpos=psort(j:end,:);
    range=min(psortpos(:,1)):pstep:max(psortpos(:,1)); %range for support of smoothed density of market clearing price
    if usesmooth==1
        [pdistr]=ksdensity(psortpos(:,1),range);
    end
end
%plot(range,pdistr)

%Start by determining the two prices between which the 'step' is, and then which point on the price grid these correspond to
for step=1:bidsteps(bidder,1)

    if bidder==1
        pstepmax=estim(step,5);
    else
        pstepmax=estim(bidstepscum(max(bidder-1,1))+step,5);
    end
    
    if step==bidsteps(bidder,1) %make sure that the last step checks prices up to zero
        pstepmin=pmin; %Actually let it be the minimum price on the grid
    else
         if bidder==1
            pstepmin=estim(step+1,5);
         else
            pstepmin=estim(bidstepscum(max(bidder-1,1))+step+1,5);
         end
    end  


    %Let's get the probability that p is strictly between the two steps and
    %weakly below next one
    i=0;
    x=size(range);
    while range(1,min(i+1,x(1,2)))<=pstepmin, if i==x(1,2), break, end, i=i+1; end
    j=i; 
    while range(1,min(j+1,x(1,2)))<pstepmax, if j==x(1,2), break, end, j=j+1; end
    der=max(j-4,1); %this will be used to approximate the derivative
    
    if range(1,min(j+1,x(1,2)))==pstepmax, k=j+1; derweak=j; else k=j; derweak=j-1; end
    if k==0 %in case only zero prices were recorded
        k=1;
        %disp(['Only zero prices!' num2str(bidder)]),
    end 
	
    if model~=2        
        if i==0, i=1; end
        if step<bidsteps(bidder,1) %under model 3 last step differs
            probwe=sum(pdistr(1,1:i)); %prob weakly below next step
        else
            if model==1
                probwe=sum(pdistr(1,1:i)); %prob weakly below next step
            else
                probwe=sum(pdistr(1,1:k)); % prob weakly below current step
            end
        end                
    else        
        probwe=sum(pdistr(1,1:k)); % weakly below current step
    end
    if j>0
        probst=sum(pdistr(1,max(i,1):j)); %prob of price between steps
    else
        probst=0; 
    end
    
%    derapprox=(probst-sum(pdistr(1,max(i,1):der)))/pstep; approximation of
%    the derivative of the probability of being strictly between the steps
if j-4>=1
    temp=4*pstep;
else
    temp=(j-1)*pstep;
end
    derapprox=(sum(pdistr(1,1:j))-sum(pdistr(1,1:der)))/temp; % approximation of the slope of probability of
                                                               % being strictly below the step
    derapproxweak=(sum(pdistr(1,1:k))-sum(pdistr(1,1:derweak)))/pstep;                                                               

    %Estimating the shading term: continuous version: "H/H_{p}"
    %Discrete version: (b_{k}-b_{k+1})*Pr(p<=b_{k+1})/(Pr(b_{k}>p>b_{k+1})
    if model~=2 %Model 1 is continuous marginal valuation, 2 is step function
                % Model 3 is cnts mv up to last step and uses price
                % optimality at the last step
        if step<bidsteps(bidder,1)  
            shade(1,step)=(pstepmax-pstepmin)*probwe/probst; 
        else
            if model==1
                shade(1,step)=0; % no shading on last step in cnts v(q,s) model
            else %in model 3 use price FOC at the last step
                shade(1,step)=probst/derapprox;
            end
            
        end
    else % we want to use: v=b+Pr(b<p)/(dPr(b<p)/db)
        % strictly speaking there should be a factor:
        % [dPr(b<=p)/db]/[dPr(b<p)/db] on b and couple of terms accounting for ties!
        if pstepmax<pstepmax*derapproxweak/derapprox+probst/derapprox %otherwise we would get that value is below bid
            shade(1,step)=-pstepmax+pstepmax*derapproxweak/derapprox+probst/derapprox;
        else
            shade(1,step)=probst/derapprox;
        end
            
        %shade(1,step)=(pstepmax-pstepmin)*probwe/probst; %This is a crude approximation of the derivative at last step!
    end
    
%Marginal valuation estimate at the current quantity-step
margval(1,step)=pstepmax+shade(1,step);

end
