function [margvalall]=margvaladjust(margvalall,cutoff,markup)
% Function replaces crazy estimates of marginal values (those above cutoff)
% by bid + markup
% it also forces the marginal values to be strictly decreasing 
% (by at least pstep per step).

global auctions aucgroupsize pstep
N=auctions/aucgroupsize;

for auctiongroup=1:N    
[estim,noncomp,bidsteps,bidstepscum,pgrid,invbidfunc,span,spannonc,updated,infoset,relevinvbid]=dataread(auctiongroup,pstep); 
datasize=size(margvalall{auctiongroup,1});
relevinvbidcolumn=[];
for i=1:size(relevinvbid,1)
    relevinvbidcolumn(end+1,1)=relevinvbid(i,1); 
    relevinvbidcolumn(end+1,1)=relevinvbid(i,2);     
end
if relevinvbidcolumn(1,1)>0
    for boot=1:size(margvalall,2)
        %round marginal values to the nearest pstep (needed for efficiency
        %calculations)
        margvalall{auctiongroup,boot}=round(margvalall{auctiongroup,boot}/pstep)*pstep;
        for bidder=1:datasize(1,1)
            for step=1:bidsteps(relevinvbidcolumn(bidder,1),1)
               %First replace NaN entries in the margval matrix with the bid+markup (``lower
               %bound''+markup on marginal valuation)
               if isnan(margvalall{auctiongroup,boot}(bidder,step))==1
                   if relevinvbidcolumn(bidder,1)>1
                       margvalall{auctiongroup,boot}(bidder,step)=estim(bidstepscum(relevinvbidcolumn(bidder,1)-1,1)+step,5)+markup;
                   else
                       margvalall{auctiongroup,boot}(bidder,step)=estim(step,5)+markup;
                   end
               end  
               % Now replace crazy values of marginal values in margval matrix with the bid (``lower
               % bound'' on marginal valuation) + markup (e.g., one percentage point)               
               if margvalall{auctiongroup,boot}(bidder,step)>=cutoff
                   if bidder>1
                       margvalall{auctiongroup,boot}(bidder,step)=estim(bidstepscum(relevinvbidcolumn(bidder,1)-1,1)+step,5)+markup;
                   else
                       margvalall{auctiongroup,boot}(bidder,step)=estim(step,5)+markup;
                   end
               end  
            end
            %corrects all margval to be nonincreasing  
            margvalall{auctiongroup,boot}(bidder,:)=sort(margvalall{auctiongroup,boot}(bidder,:),'descend');               
%            for step=1:bidsteps(bidder,1) 
%                if step<bidsteps(bidder,1)
%                    if margvalall{auctiongroup,boot}(bidder,step+1)>margvalall{auctiongroup,boot}(bidder,step)
%                         margvalall{auctiongroup,boot}(bidder,step+1)=margvalall{auctiongroup,boot}(bidder,step); %This uses the previous value as upper bound
%                    end
%                end
%            end
        end
        d=size(margvalall{auctiongroup,boot}); 
        for i=1:d(1,1) %this just simplifies coding for mkt clearing - makes marg value strictly decreasing by at least one price step     
            for j=2:d(1,2)
                if margvalall{auctiongroup,boot}(i,j)==margvalall{auctiongroup,boot}(i,j-1) && margvalall{auctiongroup,boot}(i,j)>0
                    k=1;
                    while margvalall{auctiongroup,boot}(i,min(j+k,d(1,2)))==margvalall{auctiongroup,boot}(i,j-1) && margvalall{auctiongroup,boot}(i,j)>0 && j+k<d(1,2), k=k+1; end
                    for a=1:k
                        margvalall{auctiongroup,boot}(i,j+a-1)=margvalall{auctiongroup,boot}(i,j+a-1)-a*pstep;
                    end
                end
            end
        end
        clear i j d a
    end
end    
end