function[ressup,firstcust,bids_data,agdem]=resampling_kernel(noncomp,boot,infoset,bandwidth,bids_data, drawnbidders)

% file for kernel resampling

% Sketch of the smoothed resampling algorithm: 
% 1) for each bid curve, construct a q-weighted bid
% 2) start resampling: want to draw N_c customer bids. Draw one randomly.
% 3) for each drawn customer bid: look at dealers' bids that are within bandwidth
% (ie whose customer bids were "close" to the q-weighted bid) and draw one
% of them (with uniform kernel: equal probabilities, with other kernels:
% decreasing probability in distance from q-weighted bid)
% 4) If zero customer bid drawn, draw from dealer bids with no info.
% 5) After N_c bids drawn and not N_d bids drawn yet (as N_c<N_d), draw the remaining
% dealer bids from dealer bids with no info.

global aucgroupsize bidstepscum estim resamplingdraws Group1 Group2 Group3 invbidboot boc_bids oversample supplynoise

% Routine for q-weighted bids
if isempty(bids_data) || boot==1
    bids_data=[];
    counter=1;
    data=estim; 
    if data(1,4)~=data(2,4) || data(1,8)~=data(2,8) % different bidder => record
        bids_data(1,:)=[data(1,2)  data(1,1) data(1,4) data(1,5) data(1,8)]; % record auction, submitter, bidder, q-wghtd bid, time-to-deadline
    end
    for i=2:size(data,1)
        if data(i-1,4)~=data(i,4) || data(i-1,8)~=data(i,8) , counter=1; else counter=counter+1; end % different submitter or time
        if i<size(data,1)
            if data(i,4)~=data(i+1,4) || data(i,8)~=data(i+1,8)
                temp=0;
                temp=data(i-counter+1:i,5)'*data(i-counter+1:i,7)/sum(data(i-counter+1:i,7));
                bids_data=[bids_data; data(i,2) data(i,1) data(i,4) temp data(i,8)]; % record auction, submitter, bidder, q-wghtd bid, time-to-deadline
            end
        else %treat last row carefully
            if data(end-1,4)~=data(end,4) || data(end-1,8)~=data(end,8) % last row is different bid
                bids_data=[bids_data; data(i,2) data(i,1) data(i,4) data(i,5) data(i,8)];
            else
                temp=data(i-counter+1:i,5)'*data(i-counter+1:i,7)/sum(data(i-counter+1:i,7));
                bids_data=[bids_data; data(i,2) data(i,1) data(i,4) temp data(i,8)]; % record auction, submitter, bidder, q-wghtd bid, time-to-deadline
            end
        end
    end
    % add a column to bids data which will have for each customer the
    % address of the bid by a dealer that is submitted immediately AFTER observing
    % this customer's bid
    
%     bids_data(:,end+1)=0;
%     for i=1:size(bids_data,1)
%        if bids_data(i,2)~=bids_data(i,3) % means a customer bid
%            temp=bids_data(:,1)==bids_data(i,1) & bids_data(:,2)==bids_data(i,2) & bids_data(:,2)==bids_data(:,3); % dealer's bid in that auction
%            if isempty(bids_data(temp,:))==0
%                temp2=bids_data(temp,:);
%                temp3=temp2(find(bids_data(temp,5)==min(bids_data(temp,5)),1,'first'),5);
%                temp4=find(bids_data(:,1)==bids_data(i,1) & bids_data(:,2)==bids_data(i,2) & bids_data(:,2)==bids_data(:,3) & bids_data(:,5)==temp3,1,'first');
%                if temp3<bids_data(i,5) %there is a subsequent dealer's bid
%                    bids_data(i,end)=temp4;
%                else %no updated dealer's bid
%                    bids_data(i,end)=-1;
%                end
%            else
%                bids_data(i,end)=-1;
%            end
%        end
%     end
    
    bids_data(:,end+1)=0;
    temp=size(bids_data,1);
    for i=1:size(bids_data,1)
       if bids_data(i,2)~=bids_data(i,3) % means a customer bid
           % find closest subsequent dealer bid           
           for j=1:min(5,size(bids_data,1)-i)
               if bids_data(i+j,2)==bids_data(i+j,3) 
                   if bids_data(i+j,3)==bids_data(i,2)
                        bids_data(i,end)=i+j;
                        break
                   else
                        bids_data(i,end)=-1; % no subsequent dealer bid
                        break
                   end                   
               end
           end
       end
    end
                                             
end




% %first convert infoset to bidder identities:
% for i=1:size(infoset,1)
%    for j=1:size(infoset,2)
%        if infoset(i,j)~=0
%           knownbidid(i,j)=estim(bidstepscum(infoset(i,j),1),4);
%        end
%    end
% end
% 
% %how many customer bids observed:
% sum(knownbidid(:,1)~=0) % 524 bids knowing at least 1 customer
% sum(knownbidid(:,2)~=0) % 168 knowing at least 2
% sum(knownbidid(:,3)~=0) % 54 knowing 3
% sum(knownbidid(:,4)~=0) % 22 knowing 4
% sum(knownbidid(:,5)~=0) % 9 knowing 5
% sum(knownbidid(:,6)~=0) % 1 knowing 6
% %NOTE: 
% % 1) not all of them are updated! ie some are not preceded by dealer's bid.
% % 2) some are repetitions of customers' bids - updates etc.
% 
% % none with 7

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%ADJUST THIS CORRECTION!!!
% %this is just correcting for that one guy in Group3 in 3m and 12m auctions
% %if matur~=12
%     if floor(auctiongroup/aucgroupsize)<=11
%         Group2=[Group2; Group3];
%         Group2=sort(Group2);
%     else
%         Group1=[Group1; Group3];
%         Group1=sort(Group1);
%     end
% %end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Importance sampling: bias bids towards non-zero ones
if isempty(oversample)==1;
    redfact=1;
    redfactdealer=1;
else
    redfact=oversample;
    redfactdealer=max(oversample-0.2,1);
end
  
estsize=size(estim);
Q=1; %expected value of supply for bidders
datasize=size(invbidboot);

if boot==1 %In this case the original sample of bids - hence need to correct for zero bids
    %In each auctiongroup, we should have size(Group1)*4=72 (or aucgroupsize*size(Group1) if non-default)
    % bids by submitters, and
    %size(Group2)*4=148 bids by other bidders. Let's count the nonzero bids we observe
    %for each group, then we will assign "zero" bids so that the total number
    %of bids in the data is indeed (size(Group1)+size(Group2))*4 (we need to include zero bids for
    %resampling)
    
    %participants
    auctions=1;
    participants=[0 0]; %1st col: submitters, 2nd other bidders    
    partid=zeros(116,max(estim(:,4))); %entry equals 1 if participating in auction (rows auctions, col bidders)  
    for i=1:estsize(1,1)
        if estim(max(i-1,1),2)~=estim(i,2), auctions=auctions+1; end
        partid(auctions,estim(i,4))=1;       
    end    

    for i=1:auctions
        submitters=0; otherbidders=0;
        for j=1:max(estim(:,4))        
            if partid(i,j)==1 && any(j==Group1)
                submitters=submitters+1;
            end
            if partid(i,j)==1 && any(j==Group2)
                otherbidders=otherbidders+1;
            end
        end        
        participants(i,:)=[submitters otherbidders];
    end

    %if auctiongroup~=0 %We do not run the code for all auctions at once
    %    submitterzero=72-sum(participants(:,2));
    %    otherbidderzero=148-sum(participants(:,3));
    %else
        submitterzero=size(Group1,2)*aucgroupsize-sum(participants(:,1));
        otherbidderzero=size(Group2,2)*aucgroupsize-sum(participants(:,2));
    %end
end

%Initiate a matrix for the residual supply
ressup=zeros(resamplingdraws,datasize(1,2));
agdem=zeros(resamplingdraws,datasize(1,2));
firstcust=zeros(resamplingdraws,2);

%Start iterations

for j=1:resamplingdraws
    
    drawng1=0; %reset draw counters
    drawng2=0;
    
    %Display notice that 2500 or its multiple has been completed
    %if mod(j,2500)==0 disp(['Draws completed']), disp(j), end   
    %Reset current residual supply to full level
    if supplynoise==0
        ressup(j,:)=Q;
    else
        ressup(j,:)=normrnd(Q,supplynoise);
    end
    %First draw a noncompetitive bids (on average 3.5 per auction):
    %we want for sure to be bank of canada's bid:
    k=ceil(rand*size(boc_bids,1));
    ressup(j,:)=ressup(j,:)-boc_bids(k,9); %BOC noncomp bid
    agdem(j,:)=agdem(j,:)+boc_bids(k,9);
    
    temp=noncomp(noncomp(:,3)~=12,:); %noncomp other than BOC
    i=size(temp);
    k=ceil(rand*2);
    
    if i(1,1)>0
        for nonc=1:1+k %Either 2 or 3 noncomp bids other than BOC
            n=rand*i(1,1);
            n=ceil(n);
            ressup(j,:)=ressup(j,:)-temp(n,9);
            agdem(j,:)=agdem(j,:)+temp(n,9);
        end
    end

%INFORMED DEALERS DEALT WITH IN ANOTHER M-FILE    
%     if bidder>0 %Informed dealer
%         %Now adjust residual supply for observed bids by substracting them
%         for obs=1:size(infoset,2)
%             if infoset(bidder,obs)~=0
%                 ressup(j,:)=ressup(j,:)-invbidboot(infoset(bidder,obs),:);
%                 drawng2=drawng2+1;
%             else
%                 break
%             end
%         end
%     end

    %FROM HERE THE CODE DIFFERS DUE TO KERNEL SMOOTHING
    
    %First draw customers: (and corresponding dealers)
    %for i=1:(size(Group1,2)+size(Group2,2)-1-drawng2) %start drawing N-1 bid functions with replacement (minus observed bids)
    for i=1:size(Group2,2)
        % start with customer bids
        bidgroup=0;
         if boot==1 %In this case zero bids are not in the invbidboot
             if rand>otherbidderzero/(aucgroupsize*redfact*size(Group2,2)) % draw a non-zero customer bid
                 while all(bidgroup~=Group2) %keep drawing until a bid from this group             
                     k=ceil(rand*datasize(1,1)); %First determine which bid function to draw this round
                     if any(estim(bidstepscum(k,1),4)==Group2)
                        bidgroup=estim(bidstepscum(k,1),4);
                        drawng2=drawng2+1;
                        ressup(j,:)=ressup(j,:)-invbidboot(k,:);
                        agdem(j,:)=agdem(j,:)+invbidboot(k,:);
                        % save the first drawn customer: will be replaced
                        % from the sample for an informed dealer
                        if drawng2==1
                            firstcust(j,1)=k;
                        end
                        if drawng2==2
                            firstcust(j,2)=k;
                        end
                        % Need to draw a corresponding dealer bid that was
                        % submitted having observed a sufficiently "close" customer bid based on the bandwidth:
                        qwbid=bids_data(k,4);
                        % find "close" customer bids
%KERNEL ADJUSTMENT    % (THIS CAN BE ADJUSTED FOR ALTERNATIVE KERNELS!!!)
                        closebids=find(bids_data(:,2)~=bids_data(:,3) & abs(bids_data(:,4)-qwbid)<bandwidth);
                        %find updated dealer bids following these "close"
                        dealer_closebids=[];
                        for dbid=1:size(closebids,1)                            
                            dealer_closebids=[dealer_closebids; find(infoset(:,1)==closebids(dbid,1),1,'first')];
                        end   
                        if isempty(dealer_closebids)==1 % no updated dealer bid followed this customer bid
                            dealer_closebids=find(bids_data(:,2)==bids_data(:,3) & infoset(:,1)==0);                        
                        end
                        % now draw with equal probability one of those
%KERNEL ADJUSTMENT    % (THIS CAN BE ADJUSTED FOR ALTERNATIVE KERNELS!!!)
                        k=ceil(rand*size(dealer_closebids,1));
                        drawng1=drawng1+1;
                        ressup(j,:)=ressup(j,:)-invbidboot(dealer_closebids(k,1),:);    
                        agdem(j,:)=agdem(j,:)+invbidboot(dealer_closebids(k,1),:);   
                     end
                 end
             else % draw a zero customer bid
                 drawng2=drawng2+1;
                 if drawng2==1
                    firstcust(j,1)=0;
                 end
                 if drawng2==2
                     firstcust(j,2)=0;
                 end
             end
             
         else % when (boot>1) zero bids are part of invbidboot (Last aucgroupsize*size(Group2,2) bids are customer bids including zeros) 
             k=aucgroupsize*size(Group1,2)+ceil(rand*(aucgroupsize*size(Group2,2)));                    
             drawng2=drawng2+1;
             ressup(j,:)=ressup(j,:)-invbidboot(k,:);
             agdem(j,:)=agdem(j,:)+invbidboot(k,:);
             % now again "close" dealer bid corresponding to this customer
             % bid, start with finding close customer bids:
             if drawnbidders(k,1)>0 % this is a positive customer bid
                qwbid=bids_data(drawnbidders(k,1),4);
                %positivedraws_indexes=find(drawnbidders(:,1)>0);
                % now find dealer bids that correspond to those close
                % customer bids:
                closebids=[];
                for close_ind=1:size(drawnbidders,1)
                    if drawnbidders(close_ind,1)>0
                        if bids_data(drawnbidders(close_ind,1),2)~=bids_data(drawnbidders(close_ind,1),3) && abs(bids_data(drawnbidders(close_ind,1),4)-qwbid)<bandwidth % if there is customer's bid within bandwidth
                            if drawnbidders(close_ind,3)>0 %if informed dealer's bid followed
                                closebids=[closebids; drawnbidders(close_ind,2)]; %add corresponding informed dealer's bid
                            end
                        end
                    end
                end
%KERNEL ADJUSTMENT    % (THIS CAN BE ADJUSTED FOR ALTERNATIVE KERNELS!!!)
                if isempty(closebids)==0 %at least one informed close dealer bid
                    k=ceil(rand*size(closebids,1)); % uniform kernel puts equal probability on those within bandwidth
                    ressup(j,:)=ressup(j,:)-invbidboot(closebids(k),:);
                    agdem(j,:)=agdem(j,:)+invbidboot(closebids(k),:);
                    drawng1=drawng1+1;
                % ELSE if no close informed dealer bid => draw an
                % uninformed delaer bid later                
                end
             else %zero customer bid drawn                 
                dealer_uninf=drawnbidders(drawnbidders(1:aucgroupsize*size(Group1,2),3)==0,2); % first aucgroupsize*size(Group1,2) lines are dealers. if 3rd column is zero, no customer bid observed by dealer drawn on that line
                if size(dealer_uninf,1)>0
                    k=ceil(rand*size(dealer_uninf,1)); % uniform kernel puts equal probability on those within bandwidth
                    if dealer_uninf(k)>0 % otherwise it is a zero dealer bid (non-participating dealer)
                        ressup(j,:)=ressup(j,:)-invbidboot(dealer_uninf(k),:);
                        agdem(j,:)=agdem(j,:)+invbidboot(dealer_uninf(k),:);
                    end
                else %in this case (should be virtually zero probability) all bootstrap bids are informed
                    k=ceil(rand*aucgroupsize*size(Group1,2));
                    if drawnbidders(k,2)>0 % otherwise it is a zero dealer bid (non-participating dealer)
                        ressup(j,:)=ressup(j,:)-invbidboot(drawnbidders(k,2),:);
                        agdem(j,:)=agdem(j,:)+invbidboot(drawnbidders(k,2),:);
                    end
                end                
                drawng1=drawng1+1;
             end         
                 
%              % now draw with equal probability one of those
% %KERNEL ADJUSTMENT    % (THIS CAN BE ADJUSTED FOR ALTERNATIVE KERNELS!!!)
%                         k=ceil(rand*size(dealer_closebids,1));
%                         drawng1=drawng1+1;
%                         ressup(j,:)=ressup(j,:)-invbidboot(dealer_closebids(k,1),:);    
%              firstcust(j,1)=k;
         end
    end
          
        %%%%%%%%%%% DRAW REMAINING DEALER BIDS (-1 as one dealer's bid is fixed) %%%%%%%%%%%%%%
    for i=1:size(Group1,2)-drawng1-1
         % Continue with dealers' bids, but these have to be uninformed!
         if drawng1<size(Group1,2)
             bidgroup=0;
             if boot==1 %In this case zero bids are not in the invbidboot
                 if rand>submitterzero/(aucgroupsize*redfactdealer*size(Group1,2)) %With thise probability a non-zero bid was submitted by a submitter
                     while all(bidgroup~=Group1) %keep drawing until a bid from this group
                         k=ceil(rand*(datasize(1,1)));
                         %check if this bidder belongs to group 1 & that she is
                         %uninformed
                         if any(estim(bidstepscum(k,1),4)==Group1) && infoset(k,1)<1
                             bidgroup=estim(bidstepscum(k,1),4);
                             drawng1=drawng1+1;
                             ressup(j,:)=ressup(j,:)-invbidboot(k,:);
                             agdem(j,:)=agdem(j,:)+invbidboot(k,:);
                         end
                     end
                 else
                     drawng1=drawng1+1; %Zero bid is resampled -> no change in ressup(j,:)
                 end

             else % when (boot>1) zero bids are part of invbidboot (First 72 bids with default parameters)                 
                 uninf_size=size(drawnbidders(drawnbidders(1:aucgroupsize*size(Group1,2),3)==0,2),1);
                 while bidgroup==0
                    k=ceil(rand*(aucgroupsize*size(Group1,2)));
                    % make sure it is an uninformed dealer: (otherwise draw again)
                    if uninf_size>0 % at least one uninformed dealer in bootsample
                        if drawnbidders(k,3)==0
                            bidgroup=1; % stop the loop - this is an uninformed dealer                        
                            drawng1=drawng1+1;
                            ressup(j,:)=ressup(j,:)-invbidboot(k,:);
                            agdem(j,:)=agdem(j,:)+invbidboot(k,:);
                        end
                    else
                        bidgroup=1; % stop the loop - just draw a dealer                        
                        drawng1=drawng1+1;
                        ressup(j,:)=ressup(j,:)-invbidboot(k,:);     
                        agdem(j,:)=agdem(j,:)+invbidboot(k,:);   
                    end
                 end
             end
         end
    end %ends drawing bid functions     
end



