function[teststat_alt,teststat_alt_within,test_pairs,teststat_maxmin,samplestat,avgderatbk,avgderbelowbk,allders_avgs,allders]=restr_test(margvalall,similarity_cutoff,derbkeq,derbkstrict,probintstrict,probintweak,deltaadjust, scaling)

% function that computes the test for the restriction under the alternative
% hypothesis: two dealers with same uninformed bids who later observe
% totally ordered customer bids so that winner's curse effect differs for
% them should have ordered vhats
% similarity_cutoff parameter (usually 1/2 or 1 basis point) governs how
% close the dealer q-weighted bids have to be in order to be deemed "the
% same"
% samplestat output are the differences in vhats in the sample (1st col)
% and these differences divided by their std errors (2nd col.)
% when derivatives of the distr of the market cl price are supplies, the
% mean of this deriv at p^c=b_k across k for each bidder and mean of this
% derv at b_k>p^c>b_k+1 are supplied in col 3 and 4.

global matur

if exist('scaling','var')==0
    scaling=1; %scaling factor when correcting pseudovalues by the Delta term
else
    if isempty(scaling)
        scaling=1;
    end
end
if exist('deltaadjust','var')==0
    deltaadjust=0;
else
    if isempty(deltaadjust)
        deltaadjust=0;
    end
end
if isempty(matur)
    matur=12;
end
if nargin<2
    if matur==12
        similarity_cutoff=25; % default is 1/4 of a basis point in 12m t-bills 
    else
        similarity_cutoff=10;
    end
end
if exist('derbkeq','var')==0 
    noderivatives=1;
else
    if isempty(derbkeq)==1
        noderivatives=1;
    else
        noderivatives=0;
    end
end

%matur=12;

% Routine for q-weighted bids (copied from resampling_kernel.m)

[estim_all,noncomp_all,bidsteps_all,bidstepscum_all,pgrid_all,invbidfunc_all,span,spannonc,updated_all,infoset_all,relevinvbid_all]=dataread(0,1);
    

bids_data=[];
counter=1;
data=estim_all;
if data(1,4)~=data(2,4) || data(1,8)~=data(2,8) % different bidder => record
    bids_data(1,:)=[data(1,2)  data(1,1) data(1,4) data(1,5) data(1,8)]; % record auction, submitter, bidder, q-wghtd bid, time-to-deadline
end
for i=2:size(data,1)
    if data(i-1,4)~=data(i,4) || data(i-1,8)~=data(i,8) , counter=1; else counter=counter+1; end % different submitter or time
    if i<size(data,1)
        if data(i,4)~=data(i+1,4) || data(i,8)~=data(i+1,8)
            temp=0;
            temp=data(i-counter+1:i,5)'*data(i-counter+1:i,7)/sum(data(i-counter+1:i,7));
            bids_data=[bids_data; data(i,2) data(i,1) data(i,4) temp data(i,8)]; % record auction, submitter, bidder, q-wghtd bid, time-to-deadline
        end
    else %treat last row carefully
        if data(end-1,4)~=data(end,4) || data(end-1,8)~=data(end,8) % last row is different bid
            bids_data=[bids_data; data(i,2) data(i,1) data(i,4) data(i,5) data(i,8)];
        else
            temp=data(i-counter+1:i,5)'*data(i-counter+1:i,7)/sum(data(i-counter+1:i,7));
            bids_data=[bids_data; data(i,2) data(i,1) data(i,4) temp data(i,8)]; % record auction, submitter, bidder, q-wghtd bid, time-to-deadline
        end
    end
end
% add a column to bids data which will have for each customer the
% address of the bid by a dealer that is submitted immediately AFTER observing

bids_data(:,end+1)=0;
temp=size(bids_data,1);
for i=1:size(bids_data,1)
    if bids_data(i,2)~=bids_data(i,3) % means a customer bid
        % find closest subsequent dealer bid
        for j=1:min(5,size(bids_data,1)-i)
            if bids_data(i+j,2)==bids_data(i+j,3)
                if bids_data(i+j,3)==bids_data(i,2)
                    bids_data(i,end)=i+j;
                    break
                else
                    bids_data(i,end)=-1; % no subsequent dealer bid
                    break
                end
            end
        end
    end
end

% to doublecheck earlier code, figure out updated bids independently:
upd_bid=[];
informed_bid=[];
orig_bid=[];
obs_cust_bid=[];
i=1;
while i<size(bids_data,1)
    %if size(bids_data(bids_data(:,1)==bids_data(i,1) & bids_data(:,2)==bids_data(i,2),:),1)>1
        j=0;
        upd=0;
        orig=0;
        cust=0;
        while bids_data(i+j,1)==bids_data(i,1) && bids_data(i+j,2)==bids_data(i,2)
            if bids_data(i+j,2)==bids_data(i+j,3) && orig==0 && bids_data(i+j,3)~=bids_data(min(i+j+1,size(bids_data,1)),3)
                orig=i+j;
            end
            if bids_data(i+j,2)~=bids_data(i+j,3) && orig>0
                cust=i+j;
            end
            if bids_data(i+j,2)==bids_data(i+j,3) && cust>0 && orig==0
                informed_bid=[informed_bid; i+j];
            end
            if bids_data(i+j,2)==bids_data(i+j,3) && cust>0 && orig>0 && bids_data(i+j-1,3)~=bids_data(i+j,3) 
                upd_bid=[upd_bid; i+j];
                orig_bid=[orig_bid; orig];
                obs_cust_bid=[obs_cust_bid; cust];
                if bids_data(i+j,3)~=bids_data(min(i+j+1,size(bids_data,1)),3) && bids_data(i+j,2)==bids_data(min(i+j+1,size(bids_data,1)),2)
                    cust=0; orig=i+j;
                else
                    orig=0; cust=0;
                end
            end
            if i+j+1<=size(bids_data,1)
                j=j+1;
            else
                break
            end
        end
    %end
    i=i+j;
end

%OK GOOD! same number of updated bids :o)

% now look for original dealer bids that look similar:
upd_all=bids_data(upd_bid,:);
orig_all=bids_data(orig_bid,:);
similar=zeros(size(upd_all,1),size(upd_all,1));
clear temp
%similarity_cutoff=25; %let's set 1/2 or 1 basis point for now
for i=1:size(upd_bid,1)
    similar(i,:)=abs(orig_all(:,4)-orig_all(i,4))<=similarity_cutoff;
end

%Let's replace the similar bids with zero if it is a dealer updating multiple times within an auction
for  i=1:size(similar,1)
    for j=1:size(similar,2)
        if similar(i,j)>0
            if bids_data(orig_bid(i,1),1)==bids_data(orig_bid(j,1),1) && bids_data(orig_bid(i,1),2)==bids_data(orig_bid(j,1),2) && j~=i
                similar(i,j)=0;
            end
        end
    end
end

%sum(sum(similar))
% to similar original bids, assign the observed customer bids, so that we
% can figure out if some are totally ordered:
for i=1:size(similar,1)
    for j=1:size(similar,2)
        if similar(i,j)>0
            similar(i,j)=obs_cust_bid(j);
        end
    end
end
% Now which customer bids are totally ordered?
ordered=zeros(size(similar,1));
for i=1:size(similar,1)
    temp=find(similar(i,:)>0);
    %the customer bid dealer i has seen
    seen_bid=estim_all(bidstepscum_all(similar(i,i),1)-bidsteps_all(similar(i,i),1)+1:bidstepscum_all(similar(i,i),1),[5 7]);
    for j=1:size(temp,2)
       if similar(i,i)~=similar(i,temp(1,j)) % leave out diagonal (that is the customer bid dealer i has seen)
           other_deal_seen_bid=estim_all(bidstepscum_all(similar(i,temp(1,j)),1)-bidsteps_all(similar(i,temp(1,j)),1)+1:bidstepscum_all(similar(i,temp(1,j)),1),[5 7]);
           % determine if this other customer bid is totally ordered
           % relative to the one seen by dealer i
           seen_bid(:,3)=i;
           other_deal_seen_bid(:,3)=temp(1,j);
           both_bids_p=sortrows([seen_bid; other_deal_seen_bid],[1 2]);
           both_bids_q=sortrows([seen_bid; other_deal_seen_bid],[2 1]);
           if all(both_bids_p(:,3)==both_bids_q(:,3))
              if  both_bids_q(1,3)==i
                  ordered(i,temp(1,j))=-1; % if customer bid observed by the ROW dealer is strictly smaller than the one observed by the COLUMN dealer
              else
                  ordered(i,temp(1,j))=1; 
              end                  
           end
       end
    end
end

% LOOKS GOOD!!! WE HAVE 256 ordered pairs in 3m and 112 in 12m! (BUT THAT
% IS COUNTING EACH PAIR TWICE!!!)
% AFTER ELIMINATING PAIRS OF MULTIPLE UPDATING BIDDERS WE HAVE 37 unique
% pairs to test our restriction under the alternative
disp(['Ordered pairs: ' num2str(sum(sum(ordered~=0))/2)])

% Now construct a |Ordered|x6 matrix where first 3 col's are about the updated bid by the
% dealer observing LOWER customer bid and last 3 col's about the corresponding
% updated dealer bid observing HIGHER customer bid.

% structure: 1st: auction ID, 2nd: dealer ID, 3rd: time-to-deadline (LOWER customer bid)
% 4th: auction ID, 5th: dealer ID, 6th: time-to-deadline (HIGHER customer bid)
test_pairs=[];
for i=1:size(ordered,1)
    for j=1:size(ordered,2)
        if ordered(i,j)==-1
           smaller=upd_bid(i,1);
           bigger=upd_bid(j,1);           
           test_pairs=[test_pairs; bids_data(smaller,[1 2 5]) bids_data(bigger,[1 2 5]) ]; 
        end
    end
end
test_pairs(:,end+1)=test_pairs(:,1)==test_pairs(:,4); %7th col: 1 if the ordered pair is within the same auction
disp(['Test pairs within an auction: ' num2str(sum(test_pairs(:,end)))])

% now I need to convert the test pairs back to the estimation results.
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M1_12m_auc4_gr29_O1_S0_pkernel1_5000.mat', 'margvalall', 'aucgroupsize','boc_bids', 'Group1', 'Group2', 'Group3' ,'matur', 'aucgroupsize')
%load('/home/jakub/matlab_results/cvtest/kernel_sep_09/canada_model_M1_12m_auc4_gr29_O1_S0_pkernel1_5000.mat')

% structure of bid_address: auctiongroup, address_in_margvalall, auctionID,
% delaerID, time_to_deadline, which bid in that
% auctiongroups (before update), auctionID,
% delaerID, time_to_deadline, which bid in that
% auctiongroups (after update) 
bid_address=[];
for auctiongroup=1:size(margvalall,1)
    [estim,noncomp,bidsteps,bidstepscum,pgrid,invbidfunc,span,spannonc,updated,infoset,relevinvbid]=dataread(auctiongroup,1); 
    if relevinvbid(1,1)>0
        for i=1:size(relevinvbid,1)
            bid_address=[bid_address; auctiongroup i estim(bidstepscum(relevinvbid(i,1),1),[2 4 8]) relevinvbid(i,1) estim(bidstepscum(relevinvbid(i,2),1),[2 4 8]) relevinvbid(i,2)];        
        end    
    else
        %disp(auctiongroup)
    end
end

% now save the addresses of marginal values corresponding to the UPDATED
% bids in margvalall: 1st col: auctiongroup (SMALLER cust BID), 2nd: line in margvalall, 3rd:
% line in bidsteps 4th: auctiongroup (HIGHER cust BID), 5th: line in margvalall (HIGHER cust BID)
% 6th: line in bidsteps (HIGHER cust BID)
temp=[];
temp2=[];
pair_address=[];
for i=1:size(test_pairs,1)
    temp=find(bid_address(:,7)==test_pairs(i,1) & bid_address(:,8)==test_pairs(i,2) & bid_address(:,9)==test_pairs(i,3),1,'first');    
    temp2=find(bid_address(:,7)==test_pairs(i,4) & bid_address(:,8)==test_pairs(i,5) & bid_address(:,9)==test_pairs(i,6),1,'first');    
    pair_address(i,:)=[bid_address(temp,[1 2 10]) bid_address(temp2,[1 2 10]) ];
end

temp_size=0;
for i=1:size(margvalall,1)
   temp_size=max(size(margvalall{i,1},2),temp_size);
end

% alt_restr_teststat saves the estimated marginal values for the testing
% pairs on four subsequent lines, where two lines always contain marginal
% value estimates and at which quantities

% alt_restr_teststat_within same as above, but restricted to testing pairs 
% WITHIN an auction
for i=1:size(margvalall,1)
    [estim_grp{i,1},noncomp,bidsteps_grp{i,1},bidstepscum_grp{i,1},pgrid,invbidfunc,span,spannonc,updated,infoset,relevinvbid_grp{i,1}]=dataread(i,1);     
end
avgderatbk=[0 0 0 0]; %1st col: avg der at b_k for pairs allowing across auctions, 2nd: within auctions only,
% 3rd: avg [derivative/Pr(b_k>p^c>b_k+1)] across auctions; 4th: avg [derivative/Pr(b_k>p^c>b_k+1)] within auctions 
avgderbelowbk=[0 0 0 0]; %1st col: avg der of Pr(b_k>p^c>b_k+1) for pairs allowing across auctions, 2nd: within auctions only
% 3rd: derivative across auctions divided by Pr(b_k>p^c>b_k+1); 4th: derivative within auctions divided by Pr(b_k>p^c>b_k+1)
allders=[];
allders_avgs=[];
for boot=1:size(margvalall,2)
    alt_restr_teststat{1,boot}=[];
    alt_restr_teststat_within{1,boot}=[];
    for i=1:size(test_pairs,1)
       %alt_restr_teststat{1,boot}((i-1)*2+1,:)=[margvalall{pair_address(i,1),1}(pair_address(i,2),:) zeros(1,7-size(margvalall{pair_address(i,1),1},2))];
       %alt_restr_teststat{1,boot}(i*2,:)=[margvalall{pair_address(i,3),1}(pair_address(i,4),:) zeros(1,7-size(margvalall{pair_address(i,3),1},2))];
       alt_restr_teststat{1,boot}(end+1,:)=[margvalall{pair_address(i,1),boot}(2*pair_address(i,2),:) zeros(1,7-size(margvalall{pair_address(i,1),boot},2))];
       temp=bidstepscum_grp{pair_address(i,1),1}(pair_address(i,3),1)-bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)+1;
       temp2=bidstepscum_grp{pair_address(i,1),1}(pair_address(i,3),1);
       alt_restr_teststat{1,boot}(end+1,:)=[estim_grp{pair_address(i,1),1}(temp:temp2,6)' zeros(1,7-size(estim_grp{pair_address(i,1),1}(temp:temp2,6),1))];
       alt_restr_teststat{1,boot}(end+1,:)=[margvalall{pair_address(i,4),boot}(2*pair_address(i,5),:) zeros(1,7-size(margvalall{pair_address(i,4),boot},2))];
       temp3=bidstepscum_grp{pair_address(i,4),1}(pair_address(i,6),1)-bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),1)+1;
       temp4=bidstepscum_grp{pair_address(i,4),1}(pair_address(i,6),1);
       alt_restr_teststat{1,boot}(end+1,:)=[estim_grp{pair_address(i,4),1}(temp3:temp4,6)' zeros(1,7-size(estim_grp{pair_address(i,4),1}(temp3:temp4,6),1))];
       if test_pairs(i,7)==1
            alt_restr_teststat_within{1,boot}(end+1,:)=[margvalall{pair_address(i,1),boot}(2*pair_address(i,2),:) zeros(1,7-size(margvalall{pair_address(i,1),boot},2))];
            alt_restr_teststat_within{1,boot}(end+1,:)=[estim_grp{pair_address(i,1),1}(temp:temp2,6)' zeros(1,7-size(estim_grp{pair_address(i,1),1}(temp:temp2,6),1))];
            alt_restr_teststat_within{1,boot}(end+1,:)=[margvalall{pair_address(i,4),boot}(2*pair_address(i,5),:) zeros(1,7-size(margvalall{pair_address(i,4),boot},2))];
            alt_restr_teststat_within{1,boot}(end+1,:)=[estim_grp{pair_address(i,4),1}(temp3:temp4,6)' zeros(1,7-size(estim_grp{pair_address(i,4),1}(temp3:temp4,6),1))];
       end
       if boot==1 && noderivatives==0
           validsum=probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),:)~=0;
           validsum2=probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),:)~=0;
           allders_avgs=[allders_avgs; sum(derbkeq{pair_address(i,1),boot}(2*pair_address(i,2),:))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:) ...
               sum(derbkstrict{pair_address(i,1),boot}(2*pair_address(i,2),:))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:) ...
               sum(derbkeq{pair_address(i,1),boot}(2*pair_address(i,2),validsum)./probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum))/(bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)-sum(validsum==0)) ...
                sum(derbkstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum)./probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum))/(bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)-sum(validsum==0))];
           allders_avgs=[allders_avgs; sum(derbkeq{pair_address(i,4),boot}(2*pair_address(i,5),:))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:) ...
               sum(derbkstrict{pair_address(i,4),boot}(2*pair_address(i,5),:))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:) ...
               sum(derbkeq{pair_address(i,4),boot}(2*pair_address(i,5),validsum2)./probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2))/(bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)-sum(validsum2==0)) ...
                sum(derbkstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2)./probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2))/(bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)-sum(validsum2==0))];           
           if test_pairs(i,7)==1
               temp=[ones(bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:),1) i*ones(bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:),1)];
               temp2=[ones(bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:),1) i*ones(bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:),1)];
           else
               temp=[zeros(bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:),1) i*ones(bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:),1)];
               temp2=[zeros(bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:),1) i*ones(bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:),1)];
           end           
           allders=[allders; derbkeq{pair_address(i,1),boot}(2*pair_address(i,2),1:bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:))' ...
               derbkstrict{pair_address(i,1),boot}(2*pair_address(i,2),1:bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:))' temp probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),1:bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:))'];           
           allders=[allders; derbkeq{pair_address(i,4),boot}(2*pair_address(i,5),1:bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:))' ...
               derbkstrict{pair_address(i,4),boot}(2*pair_address(i,5),1:bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:))' temp2 probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),1:bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:))'];           
           avgderatbk(1,1)=avgderatbk(1,1)+sum(derbkeq{pair_address(i,1),boot}(2*pair_address(i,2),:))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           avgderatbk(1,1)=avgderatbk(1,1)+sum(derbkeq{pair_address(i,4),boot}(2*pair_address(i,5),:))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           %,probintstrict,probintweak
           avgderatbk(1,3)=avgderatbk(1,3)+sum(derbkeq{pair_address(i,1),boot}(2*pair_address(i,2),validsum)./probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           avgderatbk(1,3)=avgderatbk(1,3)+sum(derbkeq{pair_address(i,4),boot}(2*pair_address(i,5),validsum2)./probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           avgderbelowbk(1,1)=avgderbelowbk(1,1)+sum(derbkstrict{pair_address(i,1),boot}(2*pair_address(i,2),:))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           avgderbelowbk(1,1)=avgderbelowbk(1,1)+sum(derbkstrict{pair_address(i,4),boot}(2*pair_address(i,5),:))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           avgderbelowbk(1,3)=avgderbelowbk(1,3)+sum(derbkstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum)./probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           avgderbelowbk(1,3)=avgderbelowbk(1,3)+sum(derbkstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2)./probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*size(pair_address,1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           if test_pairs(i,7)==1
               avgderatbk(1,2)=avgderatbk(1,2)+sum(derbkeq{pair_address(i,1),boot}(2*pair_address(i,2),:))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
               avgderatbk(1,2)=avgderatbk(1,2)+sum(derbkeq{pair_address(i,4),boot}(2*pair_address(i,5),:))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
               avgderatbk(1,4)=avgderatbk(1,4)+sum(derbkeq{pair_address(i,1),boot}(2*pair_address(i,2),validsum)./probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
               avgderatbk(1,4)=avgderatbk(1,4)+sum(derbkeq{pair_address(i,4),boot}(2*pair_address(i,5),validsum2)./probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
               avgderbelowbk(1,2)=avgderbelowbk(1,2)+sum(derbkstrict{pair_address(i,1),boot}(2*pair_address(i,2),:))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
               avgderbelowbk(1,2)=avgderbelowbk(1,2)+sum(derbkstrict{pair_address(i,4),boot}(2*pair_address(i,5),:))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
               avgderbelowbk(1,4)=avgderbelowbk(1,4)+sum(derbkstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum)./probintstrict{pair_address(i,1),boot}(2*pair_address(i,2),validsum))/bidsteps_grp{pair_address(i,1),1}(pair_address(i,3),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
               avgderbelowbk(1,4)=avgderbelowbk(1,4)+sum(derbkstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2)./probintstrict{pair_address(i,4),boot}(2*pair_address(i,5),validsum2))/bidsteps_grp{pair_address(i,4),1}(pair_address(i,6),:)/(2*sum(test_pairs(:,7)==1)); % sum the derivatives across the steps of the updated bid and divide by number of steps and number of updated bids
           end
       end
    end
end

  
% Now construct the difference in q-weighted marginal values:
alt_restr_q_w_diff=[];
alt_restr_within_q_w_diff=[];
for boot=1:size(margvalall,2)    
    for i=1:4:size(alt_restr_teststat_within{1,1},1)-3
       alt_restr_within_q_w_diff((i-1)/4+1,boot)=(alt_restr_teststat_within{1,boot}(i+2,:)*alt_restr_teststat_within{1,boot}(i+3,:)')/sum(alt_restr_teststat_within{1,boot}(i+3,:))-(alt_restr_teststat_within{1,boot}(i,:)*alt_restr_teststat_within{1,boot}(i+1,:)')/sum(alt_restr_teststat_within{1,boot}(i+1,:));
    end    
    for i=1:4:size(alt_restr_teststat{1,1},1)-3
       alt_restr_q_w_diff((i-1)/4+1,boot)=(alt_restr_teststat{1,boot}(i+2,:)*alt_restr_teststat{1,boot}(i+3,:)')/sum(alt_restr_teststat{1,boot}(i+3,:))-(alt_restr_teststat{1,boot}(i,:)*alt_restr_teststat{1,boot}(i+1,:)')/sum(alt_restr_teststat{1,boot}(i+1,:));
    end    
end

if deltaadjust==1
    load('collect.mat','collect')    
    alt_restr_q_w_diff=alt_restr_q_w_diff-scaling*repmat(collect(:,5),1,size(margvalall,2)  );
    alt_restr_within_q_w_diff=alt_restr_within_q_w_diff-scaling*repmat(collect(collect(:,2)==1,5),1,size(margvalall,2)  );
end

for boot=1:size(margvalall,2)  
   teststat_maxmin(1,boot)=max(alt_restr_q_w_diff(isnan(alt_restr_q_w_diff(:,boot))==0 & isinf(alt_restr_q_w_diff(:,boot))==0, boot));
   teststat_maxmin(2,boot)=min(alt_restr_q_w_diff(isnan(alt_restr_q_w_diff(:,boot))==0 & isinf(alt_restr_q_w_diff(:,boot))==0, boot));
   teststat_maxmin(5,boot)=median(alt_restr_q_w_diff(isnan(alt_restr_q_w_diff(:,boot))==0 & isinf(alt_restr_q_w_diff(:,boot))==0, boot));
   teststat_maxmin(6,boot)=mean(alt_restr_q_w_diff(isnan(alt_restr_q_w_diff(:,boot))==0 & isinf(alt_restr_q_w_diff(:,boot))==0, boot));
   teststat_maxmin(3,boot)=max(alt_restr_within_q_w_diff(isnan(alt_restr_within_q_w_diff(:,boot))==0 & isinf(alt_restr_within_q_w_diff(:,boot))==0, boot));
   teststat_maxmin(4,boot)=min(alt_restr_within_q_w_diff(isnan(alt_restr_within_q_w_diff(:,boot))==0 & isinf(alt_restr_within_q_w_diff(:,boot))==0, boot));
   teststat_maxmin(7,boot)=median(alt_restr_within_q_w_diff(isnan(alt_restr_within_q_w_diff(:,boot))==0 & isinf(alt_restr_within_q_w_diff(:,boot))==0, boot));
   teststat_maxmin(8,boot)=mean(alt_restr_within_q_w_diff(isnan(alt_restr_within_q_w_diff(:,boot))==0 & isinf(alt_restr_within_q_w_diff(:,boot))==0, boot));
end
disp(['Maturity: ' num2str(matur)])
disp(['p-value of max (diff v)>0: ' num2str(normcdf(teststat_maxmin(1,1)/std(teststat_maxmin(1,:)),0,1))])
disp(['p-value of min (diff v)<0: ' num2str(1-normcdf(teststat_maxmin(2,1)/std(teststat_maxmin(2,:)),0,1))])
disp(['p-value of mean (diff v)>0: ' num2str(normcdf(teststat_maxmin(6,1)/std(teststat_maxmin(6,:)),0,1))])
disp(['p-value of median (diff v)>0: ' num2str(normcdf(teststat_maxmin(5,1)/std(teststat_maxmin(5,:)),0,1))])

disp(['within auction pairs: p-value of max (diff v)>0: ' num2str(normcdf(teststat_maxmin(3,1)/std(teststat_maxmin(3,:)),0,1))])
disp(['within auction pairs: p-value of min (diff v)<0: ' num2str(1-normcdf(teststat_maxmin(4,1)/std(teststat_maxmin(4,:)),0,1))])
disp(['within auction pairs: p-value of mean (diff v)>0: ' num2str(normcdf(teststat_maxmin(8,1)/std(teststat_maxmin(8,:)),0,1))])
disp(['within auction pairs: p-value of median (diff v)>0: ' num2str(1-normcdf(teststat_maxmin(7,1)/std(teststat_maxmin(7,:)),0,1))])

for i=1:size(alt_restr_q_w_diff,1)
   teststat_alt(i,1)=std(alt_restr_q_w_diff(i,isnan(alt_restr_q_w_diff(i,:))==0 & isinf(alt_restr_q_w_diff(i,:))==0 & abs(alt_restr_q_w_diff(i,:))<10e4));   
end
for i=1:size(alt_restr_within_q_w_diff,1)
   teststat_alt_within(i,1)=std(alt_restr_within_q_w_diff(i,isnan(alt_restr_within_q_w_diff(i,:))==0 & isinf(alt_restr_within_q_w_diff(i,:))==0 & abs(alt_restr_within_q_w_diff(i,:))<10e4));
end

teststat_alt(:,2:4)=[alt_restr_q_w_diff(:,1) alt_restr_q_w_diff(:,1)./teststat_alt(:,1)<norminv(0.05,0,1) normcdf(alt_restr_q_w_diff(:,1)./teststat_alt(:,1),0,1)];
teststat_alt_within(:,2:4)=[alt_restr_within_q_w_diff(:,1) alt_restr_within_q_w_diff(:,1)./teststat_alt_within(:,1)<norminv(0.05,0,1) normcdf(alt_restr_within_q_w_diff(:,1)./teststat_alt_within(:,1),0,1)];

samplestat=alt_restr_q_w_diff(isnan(alt_restr_q_w_diff(:,1))==0 & isinf(alt_restr_q_w_diff(:,1))==0, 1);
j=1;
for i=1:size(alt_restr_q_w_diff,1)
    if isnan(alt_restr_q_w_diff(i,1))==0 && isinf(alt_restr_q_w_diff(i,1))==0
       samplestat(j,2)=samplestat(j,1)/std(alt_restr_q_w_diff(i,isnan(alt_restr_q_w_diff(i,:))==0 & isinf(alt_restr_q_w_diff(i,:))==0));
       % indicator if pair within same auction
       samplestat(j,3)=test_pairs(i,7);
       j=j+1;
    end
end
if noderivatives==0
    allders(:,[6 7])=[allders(:,1)./allders(:,5) allders(:,2)./allders(:,5)];
end
