function [testvector, testindividual, resultsinfo, restr_althypo,restr_samplestat,outliers]=teststat_construct(filename,cutoff,multiple,adjust_by_neighbors,markup_par,deltaadjust,scaling)

%This function displays and outputs the results of all tests, including statistics on trimming.
% Arguments: filename = which file to load the data from (including the path)
% cutoff = marg values above this are trimmed (can be set to Inf when only NaN will be trimmed)
% multiple = markup is set to 100 basis points for 3m - multiple is a
% parameter controlling how much bigger the markup for 12m should be.
% (Default is 4)
% adjust_by_neighbors: if few Inf or NaN estimates should be substituted by
%   closeby estimates
% Output described below (and in the results excel table legend),
% restr_samplestat are differences on the 37 identified pairs (in 12-m
% t-bills)

%3/12/2010: corrected re-centering of bootstrap distribution
%filename='/home/jakub/matlab_results/cvtest/kernel_dec_09/canada_model_M1_3m_auc1_gr116_O1_S0_pkernel1_25.mat';
%filename='h:\canada_model_M1_3m_auc1_gr116_O1_S0_pkernel1_25.mat';

if exist('deltaadjust','var')==0
    deltaadjust=0;
end
if exist('scaling','var')==0
    scaling=[];
end
trimming=0;
if exist('adjust_by_neighbors','var')==0
    adjust_by_neighbors=1; % if a marginal value is Inf or NaN - 
                           %adjust by adding the mark-up estimated 
                           %on a neighboring step if possible, if not possible adjust by the default mark-up
end

outliers=[];

if exist('cutoff','var')==0
    setcutoff=1;
else
    if isempty(cutoff)
        setcutoff=1;
    else
        setcutoff=0;
    end
end
if exist('multiple','var')==0
    multiple=4;
end
if exist('markup_par','var')==0
    markup_par=2500;
end

%clear
format('short')
global aucgroupsize model pgrid pstep resamplingdraws bidstepscum bidsteps estim bootdraws Group1 Group2 Group3 nbidfun invbidboot boc_bids matur oversample supplynoise
disp('*****************************************************************************')
pstep=1;
testlevel=0.95;

load(filename)

aucgroupsize=116/size(margvalall,1);
bootdraws=size(margvalall,2);
% re-center marginal values: (correct if Inf or Nan or crazy value by
% bid+markup)
trimmed=[];
margvalall_unc=margvalall;
for auctiongroup=1:size(margvalall,1)
    trimmed{auctiongroup,1}=zeros(size(margvalall{auctiongroup,1}));
    [estim,noncomp,bidsteps,bidstepscum,pgrid,invbidfunc,span,spannonc,updated,infoset,relevinvbid]=dataread(auctiongroup,pstep); %Parameter=which group of the four auctions to read and size of step on price grid\
    if matur==12 
        markup=multiple*markup_par; %100 basis points in 3m case under default (2500)
        if setcutoff==1
            %cutoff=Inf; 
            %cutoff=1000000; 
            cutoff=max(estim(:,5))+markup; % max observed bid is 979,930 in 12m (std is 10,972)        
        end
    else
        markup=markup_par;        
        if setcutoff==1           
            %cutoff=1000000; 
            %cutoff=Inf;         
            cutoff=max(estim(:,5))+markup; % max observed bid is 994,970 in 3m (std is 3,232.2)        
        end
    end
     
    %correct few NaN and Inf's and crazy estimates on the sample vhats - those that will be used for re-centering  
    if relevinvbid(1,1)>0
        for bidder=1:size(relevinvbid,1)
            for i=1:bidsteps(relevinvbid(bidder,1))
                if margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i)>cutoff || isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i)) || isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i))
                    if relevinvbid(bidder,1)>1
                        if adjust_by_neighbors==1
                            if i==1
                                if i<bidsteps(relevinvbid(bidder,1)) && margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1)<=cutoff && isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1))==0
                                   markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1)-estim(bidstepscum(relevinvbid(bidder,1)-1,1)+i+1,5); % estimated markup at last step
                                else
                                   markup2=markup; 
                                end                            
                            else
                                if isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i-1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i-1))==0
                                    markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i-1)-estim(bidstepscum(relevinvbid(bidder,1)-1,1)+i-1,5); % estimated markup at last step
                                else
                                    markup2=markup;
                                end
                            end
                        else
                            markup2=markup;
                        end
                         margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i)=estim(bidstepscum(relevinvbid(bidder,1)-1,1)+i,5)+markup2;
                         margvalall{auctiongroup,1}(2*(bidder-1)+1,i)=estim(bidstepscum(relevinvbid(bidder,1)-1,1)+i,5)+markup2;
                         trimmed{auctiongroup,1}(2*(bidder-1)+1,i)=1;
                    else
                        if adjust_by_neighbors==1
                            if i==1
                                if i<bidsteps(relevinvbid(bidder,1)) && margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1)<=cutoff && isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1))==0
                                    markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i+1)-estim(i+1,5); % estimated markup at last step
                                else
                                    markup2=markup;
                                end
                            else
                                if isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i-1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i-1))==0
                                    markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i-1)-estim(i-1,5); % estimated markup at last step
                                else
                                    markup2=markup;
                                end
                            end
                        else
                            markup2=markup;
                        end
                        margvalall_unc{auctiongroup,1}(2*(bidder-1)+1,i)=estim(i,5)+markup2;
                        margvalall{auctiongroup,1}(2*(bidder-1)+1,i)=estim(i,5)+markup2;
                        trimmed{auctiongroup,1}(2*(bidder-1)+1,i)=1;
                    end
                end
            end
            for i=1:bidsteps(relevinvbid(bidder,2))
                if margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i)>cutoff || isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i)) || isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i))
                    if relevinvbid(bidder,2)>1
                        if adjust_by_neighbors==1
                            if i==1
                                if i<bidsteps(relevinvbid(bidder,2)) && margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1)<=cutoff && isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1))==0
                                   markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1)-estim(bidstepscum(relevinvbid(bidder,2)-1,1)+i+1,5); % estimated markup at last step
                                else
                                   markup2=markup; 
                                end                            
                            else
                                if isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i-1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i-1))==0
                                    markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i-1)-estim(bidstepscum(relevinvbid(bidder,2)-1,1)+i-1,5); % estimated markup at last step                            
                                else
                                    markup2=markup; 
                                end
                            end
                        else
                            markup2=markup;
                        end
                        margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i)=estim(bidstepscum(relevinvbid(bidder,2)-1,1)+i,5)+markup2; 
                        margvalall{auctiongroup,1}(2*(bidder-1)+2,i)=estim(bidstepscum(relevinvbid(bidder,2)-1,1)+i,5)+markup2; 
                        trimmed{auctiongroup,1}(2*(bidder-1)+2,i)=1;
                    else
                        if adjust_by_neighbors==1
                            if i==1
                                if i<bidsteps(relevinvbid(bidder,2)) && margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1)<=cutoff && isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1))==0
                                    markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i+1)-estim(i+1,5); % estimated markup at last step
                                else
                                    markup2=markup;
                                end
                            else
                                if isnan(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i-1))==0 && isinf(margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i-1))==0
                                    markup2=margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i-1)-estim(i-1,5); % estimated markup at last step
                                else
                                    markup2=markup;
                                end
                            end
                        else
                            markup2=markup;
                        end
                        margvalall_unc{auctiongroup,1}(2*(bidder-1)+2,i)=estim(i,5)+markup2;
                        margvalall{auctiongroup,1}(2*(bidder-1)+2,i)=estim(i,5)+markup2;
                        trimmed{auctiongroup,1}(2*(bidder-1)+2,i)=1;
                    end
                end
            end
        end
    end
  
    for boot=1:size(margvalall,2) %boot
        if boot>1
            trimmed{auctiongroup,boot}=zeros(size(margvalall{auctiongroup,boot}));
        end
        for bidder=1:size(relevinvbid,1)
            if relevinvbid(1,1)>0
                for i=1:bidsteps(relevinvbid(bidder,1))
                    markup2=markup;                    
                    if margvalall{auctiongroup,boot}(2*(bidder-1)+1,i)>cutoff || isnan(margvalall{auctiongroup,boot}(2*(bidder-1)+1,i)) || isinf(margvalall{auctiongroup,boot}(2*(bidder-1)+1,i))
                        if relevinvbid(bidder,1)>1
                            if adjust_by_neighbors==1
                                if i==1
                                    if i<bidsteps(relevinvbid(bidder,1)) && isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i+1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i+1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i+1)-estim(bidstepscum(relevinvbid(bidder,1)-1,1)+i+1,5); % estimated markup at last step
                                    end
                                else
                                    if isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i-1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i-1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i-1)-estim(bidstepscum(relevinvbid(bidder,1)-1,1)+i-1,5); % estimated markup at last step
                                    end
                                end
                            end
                            margvalall{auctiongroup,boot}(2*(bidder-1)+1,i)=estim(bidstepscum(relevinvbid(bidder,1)-1,1)+i,5)+markup2; % if crazy, it is bid plus markup
                            trimmed{auctiongroup,boot}(2*(bidder-1)+1,i)=1;
                        else
                            if adjust_by_neighbors==1
                                if i==1
                                    if i<bidsteps(relevinvbid(bidder,1)) && isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i+1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i+1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i+1)-estim(i+1,5); % estimated markup at last step
                                    end
                                else
                                    if isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i-1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i-1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,i-1)-estim(i-1,5); % estimated markup at last step
                                    end
                                end
                            end
                            margvalall{auctiongroup,boot}(2*(bidder-1)+1,i)=estim(i,5)+markup2; % if crazy, it is bid plus markup
                            trimmed{auctiongroup,boot}(2*(bidder-1)+1,i)=1;
                        end
                    end
                end
                for i=1:bidsteps(relevinvbid(bidder,2))
                    markup2=markup;                   
                    if margvalall{auctiongroup,boot}(2*(bidder-1)+2,i)>cutoff || isnan(margvalall{auctiongroup,boot}(2*(bidder-1)+2,i)) || isinf(margvalall{auctiongroup,boot}(2*(bidder-1)+2,i))
                        if relevinvbid(bidder,2)>1
                            if adjust_by_neighbors==1
                                if i==1
                                    if i<bidsteps(relevinvbid(bidder,2)) && isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i+1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i+1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i+1)-estim(bidstepscum(relevinvbid(bidder,2)-1,1)+i+1,5); % estimated markup at last step
                                    end
                                else
                                    if isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i-1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i-1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i-1)-estim(bidstepscum(relevinvbid(bidder,2)-1,1)+i-1,5); % estimated markup at last step
                                    end
                                end
                            end
                            margvalall{auctiongroup,boot}(2*(bidder-1)+2,i)=estim(bidstepscum(relevinvbid(bidder,2)-1,1)+i,5)+markup2; % if crazy, it is bid plus markup
                            trimmed{auctiongroup,boot}(2*(bidder-1)+2,i)=1;
                        else
                            if adjust_by_neighbors==1
                                if i==1
                                    if i<bidsteps(relevinvbid(bidder,2)) && isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i+1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i+1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i+1)-estim(i+1,5); % estimated markup at last step
                                    end
                                else
                                    if isnan(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i-1))==0 && isinf(margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i-1))==0
                                        markup2=margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,i-1)-estim(i-1,5); % estimated markup at last step
                                    end
                                end
                            end
                            margvalall{auctiongroup,boot}(2*(bidder-1)+2,i)=estim(i,5)+markup2; % if crazy, it is bid plus markup
                            trimmed{auctiongroup,boot}(2*(bidder-1)+2,i)=1;
                        end
                    end
                end
            end
        end
        margvalall{auctiongroup,boot}=margvalall{auctiongroup,boot}(:,:)-margvalall_unc{auctiongroup,1}(:,:); %Re-centering for bootstrap       
    end
end

% for i=1:size(margvalall,1)
%     if max(max(margvalall{i,1}))>0;
%         disp(i)
%         pause
%     end
% end

    

%Monotonicity test and equality test for individual hypotheses
monottest=[];
equaltest=[];
for auctiongroup=1:size(margvalall,1)
    [estim,noncomp,bidsteps,bidstepscum,pgrid,invbidfunc,span,spannonc,updated,infoset,relevinvbid]=dataread(auctiongroup,pstep); %Parameter=which group of the four auctions to read and size of step on price grid       
    for bidder=1:size(relevinvbid,1)
        if relevinvbid(1,1)>0
            totalsteps=bidsteps(relevinvbid(bidder,1))+bidsteps(relevinvbid(bidder,2));
            monottest=[monottest ; zeros(1,bootdraws)];            
            for boot=1:bootdraws                
                temptest{bidder,boot}=zeros(2,totalsteps);                
                %pool estimates: (1st line: margval, 2nd line: quantity)
                if boot==1 % want the actual sample estimates (by which we are centering all others)
                    temptest{bidder,boot}(1,:)=[margvalall_unc{auctiongroup,boot}(2*(bidder-1)+1,1:bidsteps(relevinvbid(bidder,1))) ...
                        margvalall_unc{auctiongroup,boot}(2*(bidder-1)+2,1:bidsteps(relevinvbid(bidder,2)))];
                else
                    temptest{bidder,boot}(1,:)=[margvalall{auctiongroup,boot}(2*(bidder-1)+1,1:bidsteps(relevinvbid(bidder,1))) ...
                        margvalall{auctiongroup,boot}(2*(bidder-1)+2,1:bidsteps(relevinvbid(bidder,2)))];                                    
                end
                % add in the quantity demands:
                if relevinvbid(bidder,1)>1
                    temptest{bidder,boot}(2,:)=[estim(bidstepscum(relevinvbid(bidder,1)-1,1)+1:bidstepscum(relevinvbid(bidder,1)-1,1)+bidsteps(relevinvbid(bidder,1),1),7) ; ...
                        estim(bidstepscum(relevinvbid(bidder,2)-1,1)+1:bidstepscum(relevinvbid(bidder,2)-1,1)+bidsteps(relevinvbid(bidder,2),1),7)]';
                else
                    temptest{bidder,boot}(2,:)=[estim(1:bidsteps(relevinvbid(bidder,1),1),7) ; ...
                        estim(bidstepscum(relevinvbid(bidder,2)-1,1)+1:bidstepscum(relevinvbid(bidder,2)-1,1)+bidsteps(relevinvbid(bidder,2),1),7)]';                             
                end                                              
                                
                sortedvals=sortrows(temptest{bidder,boot}',[2 -1]); %sort marginal values estimates based on quantity demanded
                if size(temptest{bidder,boot},2)>=2 % in M3 in few bootstrap draws there is just one quantity estimate.
                    if max(sortedvals(2:end,1)- sortedvals(1:end-1,1))<=0
                        monottest(end,boot)=0;
                    else
                        monottest(end,boot)=max(sortedvals(2:end,1)-sortedvals(1:end-1,1));
                    end
                    sameqs=find(sortedvals(1:end-1,2)==sortedvals(2:end,2)); %two successive rows are for the same quantity
                    if isempty(sameqs)==0
                        for i=1:size(sameqs,1)                  
                              if boot==1 
                                  equaltest=[equaltest; zeros(1,bootdraws)];
                                  if aucgroupsize==1 && matur==3 && size(equaltest,1)==520 %this displays the one problematic hypothesis in 3-m 1-auc case
                                      %disp([num2str(auctiongroup) ' ' num2str(bidder) ' ' num2str(sortedvals(sameqs(i,1),1)) ' ' num2str(sortedvals(sameqs(i,1)+1,1))])
                                      %disp([num2str(sortedvals(sameqs(i,1),2)) ' ' num2str(sortedvals(sameqs(i,1)+1,2))])
                                      %disp('Bids: ')
                                      %disp(estim(bidstepscum(31,1)+1:bidstepscum(31,1)+bidsteps(32,1),5))
                                      %disp(estim(bidstepscum(33,1)+1:bidstepscum(33,1)+bidsteps(34,1),5))
                                  end
                                  equaltest(end,boot)=abs(sortedvals(sameqs(i,1),1)-sortedvals(sameqs(i,1)+1,1));
                                  %if equaltest(end,boot)>2000
                                  %    disp(auctiongroup)
                                  %    disp(bidder)
                                  %    disp(boot)  
                                  %    %pause
                                  %end
                              else  % the dimension of equaltest has been increased by size(sameqs,1) during the boot=1 loop.                              
                                  equaltest(end-size(sameqs,1)+i,boot)=abs(sortedvals(sameqs(i,1),1)-sortedvals(sameqs(i,1)+1,1));
                              end                                
                        end
                    end
                end
            end 
            % find the outliers:
            for i=1:size(sameqs,1)
                if std(equaltest(end-size(sameqs,1)+i,2:end))>0
                    if equaltest(end-size(sameqs,1)+i,1)/std(equaltest(end-size(sameqs,1)+i,2:end))>20 && std(equaltest(end-size(sameqs,1)+i,2:end))>0
                        outliers=[outliers; auctiongroup bidder i];                    
                    end
                end
            end
        end
        %if max(max(equaltest(:,1)))>1e5
        %    disp(auctiongroup)
        %    disp(bidder)
            %pause
        %end
%         if size(equaltest,1)>=490
%             disp(auctiongroup)
%             disp(bidder)
%             disp(size(equaltest,1))
%             pause
%         end
    end
end
% now we took the difference of the re-centered marginal value. Let's scale
% by the std deviation (estimated by boostrapping) of each such difference

temp=find(monottest>1e4);
monottest2=monottest;
temp2=find(equaltest>1e4);
equaltest2=equaltest;
if trimming==1
    monottest2(temp)=0;
    equaltest2(temp2)=0;
end
std_mono=std(monottest2(:,2:end)')';
%eliminate those with zero std deviation
monottest2_stud=monottest2(std_mono>0,:)./repmat(std_mono(std_mono>0),1,bootdraws);
foc_stud_mono=max(monottest2_stud);
med_stud_mono=median(monottest2_stud);
%99th percentile:
perc_stud_mono=prctile(monottest2_stud,95);

if exist('finishtime','var')
    disp(datestr(finishtime))
end

if exist('bandw','var')==0
    bandw=Inf;
end    

disp (['Maturity: ' num2str(matur) ' Model: ' num2str(model) ' Auctions grouped: ' num2str(aucgroupsize) ' Kernelsize: ' num2str(bandw) ' Cutoff: ' num2str(cutoff)])
disp (['Correct problem mvs by neighbors: ' num2str(adjust_by_neighbors) ' Markup parameter: ' num2str(markup_par) ' 12M adjustment: ' num2str(multiple)])
disp('------------------------------------------------------------------------------')
    
if foc_stud_mono(1,1)>prctile(foc_stud_mono,testlevel*100)
    disp(['FOS_stud_mono REJECTS with FOS=' num2str(foc_stud_mono(1,1)) ' critval=' num2str(prctile(foc_stud_mono,testlevel*100))])
else
    disp(['FOS_stud_mono DOES NOT REJECT with FOS=' num2str(foc_stud_mono(1,1)) ' critval=' num2str(prctile(foc_stud_mono,testlevel*100))])
end
if isempty(find(foc_stud_mono(1,1)>=sort(foc_stud_mono(2:end)),1,'last')) && foc_stud_mono(1,1)<min(foc_stud_mono(2:end))
    foc_stud_mono_pv=0;
else
    if foc_stud_mono(1,1)>max(foc_stud_mono(2:end))
        foc_stud_mono_pv=1;
    else
        foc_stud_mono_pv=find(foc_stud_mono(1,1)>=sort(foc_stud_mono(2:end)),1,'last')/size(foc_stud_mono(2:end),2);
    end
end
disp(['pvalue: ' num2str(foc_stud_mono_pv)])
disp(['Std dev foc_mono: ' num2str(std(foc_stud_mono))])

if med_stud_mono(1,1)>prctile(med_stud_mono,testlevel*100)
    disp(['Median_stud_mono REJECTS with Median=' num2str(med_stud_mono(1,1)) ' critval=' num2str(prctile(med_stud_mono,testlevel*100))])
else
    disp(['Median_stud_mono DOES NOT REJECT with Median=' num2str(med_stud_mono(1,1)) ' critval=' num2str(prctile(med_stud_mono,testlevel*100))])
end
if isempty(find(med_stud_mono(1,1)>=sort(med_stud_mono(2:end)),1,'last')) && med_stud_mono(1,1)<min(med_stud_mono(2:end))
    med_stud_mono_pv=0;
else
    if med_stud_mono(1,1)>max(med_stud_mono(2:end))
        med_stud_mono_pv=1;
    else
        med_stud_mono_pv=find(med_stud_mono(1,1)>=sort(med_stud_mono(2:end)),1,'last')/size(med_stud_mono(2:end),2);
    end
end
disp(['pvalue: ' num2str(med_stud_mono_pv)])
disp(['Std dev median_mono: ' num2str(std(med_stud_mono))])

if perc_stud_mono(1,1)>prctile(perc_stud_mono,testlevel*100)
    disp(['95th_stud_mono REJECTS with 95th=' num2str(perc_stud_mono(1,1)) ' critval=' num2str(prctile(perc_stud_mono,testlevel*100))])
else
    disp(['95th_stud_mono DOES NOT REJECT with 95th=' num2str(perc_stud_mono(1,1)) ' critval=' num2str(prctile(perc_stud_mono,testlevel*100))])
end
if isempty(find(perc_stud_mono(1,1)>=sort(perc_stud_mono(2:end)),1,'last')) && perc_stud_mono(1,1)<min(perc_stud_mono(2:end))
    perc_stud_mono_pv=0;
else
    if perc_stud_mono(1,1)>max(perc_stud_mono(2:end))
        perc_stud_mono_pv=1;
    else
        perc_stud_mono_pv=find(perc_stud_mono(1,1)>=sort(perc_stud_mono(2:end)),1,'last')/size(perc_stud_mono(2:end),2);
    end
end
disp(['pvalue: ' num2str(perc_stud_mono_pv)])
disp(['Std dev 95perc_mono: ' num2str(std(perc_stud_mono))])

sq_stud_mono=sum(monottest2_stud.^2);
if sq_stud_mono(1,1)>prctile(sq_stud_mono,testlevel*100)
    disp(['SQ_stud_mono REJECTS with SQ=' num2str(sq_stud_mono(1,1)) ' critval=' num2str(prctile(sq_stud_mono,testlevel*100))])
else
    disp(['SQ_stud_mono DOES NOT REJECT with SQ=' num2str(sq_stud_mono(1,1)) ' critval=' num2str(prctile(sq_stud_mono,testlevel*100))])
end
if isempty(find(sq_stud_mono(1,1)>=sort(sq_stud_mono(2:end)),1,'last')) && sq_stud_mono(1,1)<min(sq_stud_mono(2:end))
    sq_stud_mono_pv=0;
else
    if sq_stud_mono(1,1)>max(sq_stud_mono(2:end))
        sq_stud_mono_pv=1;
    else
        sq_stud_mono_pv=find(sq_stud_mono(1,1)>=sort(sq_stud_mono(2:end)),1,'last')/size(sq_stud_mono(2:end),2);
    end
end
disp(['pvalue: ' num2str(sq_stud_mono_pv)])
disp(['Std dev sq_mono: ' num2str(std(sq_stud_mono)) ' Chi2 crit value: ' num2str(chi2inv(0.05,sum(std_mono>0)))])

% EQUALITY TESTS:
std_equal=std(equaltest2(:,2:end)')';
equaltest2_stud=equaltest2(std_equal>0,:)./repmat(std_equal(std_equal>0),1,bootdraws);

%this one hypothesis (395) causes rejection in 3-month 1-auction resampling
%equaltest2_stud=equaltest2_stud([1:394 396:end],:);

foc_stud_eq=max(equaltest2_stud);
med_stud_eq=median(equaltest2_stud);
perc_stud_eq=prctile(equaltest2_stud,95);

if foc_stud_eq(1,1)>prctile(foc_stud_eq,testlevel*100)
    disp(['FOS_stud_eq REJECTS with FOS=' num2str(foc_stud_eq(1,1)) ' critval=' num2str(prctile(foc_stud_eq,testlevel*100))])
else
    disp(['FOS_stud_eq DOES NOT REJECT with FOS=' num2str(foc_stud_eq(1,1)) ' critval=' num2str(prctile(foc_stud_eq,testlevel*100))])
end
if isempty(find(foc_stud_eq(1,1)>=sort(foc_stud_eq(2:end)),1,'last')) && foc_stud_eq(1,1)<min(foc_stud_eq(2:end))
    foc_stud_eq_pv=0;
else
    if foc_stud_eq(1,1)>max(foc_stud_eq(2:end))
        foc_stud_eq_pv=1;
    else
        foc_stud_eq_pv=find(foc_stud_eq(1,1)>=sort(foc_stud_eq(2:end)),1,'last')/size(foc_stud_eq(2:end),2);
    end
end
disp(['pvalue: ' num2str(foc_stud_eq_pv)])
disp(['Std dev fos_eq: ' num2str(std(foc_stud_eq))])

if med_stud_eq(1,1)>prctile(med_stud_eq,testlevel*100)
    disp(['Median_stud_eq REJECTS with Median=' num2str(med_stud_eq(1,1)) ' critval=' num2str(prctile(med_stud_eq,testlevel*100))])
else
    disp(['Median_stud_eq DOES NOT REJECT with Median=' num2str(med_stud_eq(1,1)) ' critval=' num2str(prctile(med_stud_eq,testlevel*100))])
end
if isempty(find(med_stud_eq(1,1)>=sort(med_stud_eq(2:end)),1,'last')) && med_stud_eq(1,1)<min(med_stud_eq(2:end))
    med_stud_eq_pv=0;
else
    if med_stud_eq(1,1)>max(med_stud_eq(2:end))
        med_stud_eq_pv=1;
    else
        med_stud_eq_pv=find(med_stud_eq(1,1)>=sort(med_stud_eq(2:end)),1,'last')/size(med_stud_eq(2:end),2);
    end
end
disp(['pvalue: ' num2str(med_stud_eq_pv)])
disp(['Std dev median_eq: ' num2str(std(med_stud_eq))])

if perc_stud_eq(1,1)>prctile(perc_stud_eq,testlevel*100)
    disp(['95th prctile_stud_eq REJECTS with 95th=' num2str(perc_stud_eq(1,1)) ' critval=' num2str(prctile(perc_stud_eq,testlevel*100))])
else
    disp(['95th_stud_eq DOES NOT REJECT with 95th=' num2str(perc_stud_eq(1,1)) ' critval=' num2str(prctile(perc_stud_eq,testlevel*100))])
end
if isempty(find(perc_stud_eq(1,1)>=sort(perc_stud_eq(2:end)),1,'last')) && perc_stud_eq(1,1)<min(perc_stud_eq(2:end))
    perc_stud_eq_pv=0;
else
    if perc_stud_eq(1,1)>max(perc_stud_eq(2:end))
        perc_stud_eq_pv=1;
    else
        perc_stud_eq_pv=find(perc_stud_eq(1,1)>=sort(perc_stud_eq(2:end)),1,'last')/size(perc_stud_eq(2:end),2);
    end
end
disp(['pvalue: ' num2str(perc_stud_eq_pv)])
disp(['Std dev 95th_eq: ' num2str(std(perc_stud_eq))])

sq_stud_eq=sum(equaltest2_stud.^2);
if sq_stud_eq(1,1)>prctile(sq_stud_eq,testlevel*100)
    disp(['SQ_stud_eq REJECTS with SQ=' num2str(sq_stud_eq(1,1)) ' critval=' num2str(prctile(sq_stud_eq,testlevel*100))])
else
    disp(['SQ_stud_eq DOES NOT REJECT with SQ=' num2str(sq_stud_eq(1,1)) ' critval=' num2str(prctile(sq_stud_eq,testlevel*100))])
end
if isempty(find(sq_stud_eq(1,1)>=sort(sq_stud_eq(2:end)),1,'last')) && sq_stud_eq(1,1)<min(sq_stud_eq(2:end))
    sq_stud_eq_pv=0;
else
    if sq_stud_eq(1,1)>max(sq_stud_eq(2:end))
        sq_stud_eq_pv=1;
    else
        sq_stud_eq_pv=find(sq_stud_eq(1,1)>=sort(sq_stud_eq(2:end)),1,'last')/size(sq_stud_eq(2:end),2);
    end
end
disp(['pvalue: ' num2str(sq_stud_eq_pv)])
disp(['Std dev sq_eq: ' num2str(std(sq_stud_eq)) ' Chi2 crit value: ' num2str(chi2inv(0.05,sum(std_equal>0)))])    

disp('*********************************')

trimmed_sample=0;
trimmed_all=0;
observations_sample=0;
observations_all=0;
for j=1:size(trimmed,2)
    for i=1:size(trimmed,1)
       temp=margvalall_unc{i,j}>0 + isnan(margvalall_unc{i,j});
       if j==1
           trimmed_sample=sum(sum(trimmed{i,j}))+trimmed_sample;           
           observations_sample=observations_sample+sum(sum(temp));
       end
       observations_all=observations_all+sum(sum(temp));
       trimmed_all=trimmed_all+sum(sum(trimmed{i,j}));
    end
end
disp(['Trimmed in sample: ' num2str(trimmed_sample) ' out of ' num2str(observations_sample) ' Rate: ' num2str(trimmed_sample/observations_sample) ])
disp(['Trimmed overall: ' num2str(trimmed_all) ' out of ' num2str(observations_all) ' Rate: ' num2str(trimmed_all/observations_all) ])

disp('*****************************************************************************')

testvector=[matur model aucgroupsize bandw; ...
    foc_stud_mono(1,1) prctile(foc_stud_mono,testlevel*100) std(foc_stud_mono) foc_stud_mono_pv; ...
    med_stud_mono(1,1) prctile(med_stud_mono,testlevel*100) std(med_stud_mono) med_stud_mono_pv; ...
    perc_stud_mono(1,1) prctile(perc_stud_mono,testlevel*100) std(foc_stud_mono) perc_stud_mono_pv; ...
    sq_stud_mono(1,1) prctile(sq_stud_mono,testlevel*100) std(sq_stud_mono)  sq_stud_mono_pv; ...    
    foc_stud_eq(1,1) prctile(foc_stud_eq,testlevel*100) std(foc_stud_eq) foc_stud_eq_pv; ...
    med_stud_eq(1,1) prctile(med_stud_eq,testlevel*100) std(med_stud_eq) med_stud_eq_pv; ...
    perc_stud_eq(1,1) prctile(perc_stud_eq,testlevel*100) std(perc_stud_eq) perc_stud_eq_pv; ...
    sq_stud_eq(1,1) prctile(sq_stud_eq,testlevel*100) std(sq_stud_eq) sq_stud_eq_pv; ...
    trimmed_sample observations_sample trimmed_sample/observations_sample chi2inv(0.05,sum(std_mono>0)); ...
    trimmed_all observations_all trimmed_all/observations_all chi2inv(0.05,sum(std_equal>0)) ; ...
    cutoff multiple adjust_by_neighbors markup_par];

%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Restriction under the alternative - construct the test if not already
% saved in the datafile - use un-centered marginal value estimates.
if exist('teststat_alt','var')==0 || exist('samplestat_restr','var')==0 
    if matur==12
        [teststat_alt,teststat_alt_within,test_pairs,teststat_maxmin,samplestat_restr]=restr_test(margvalall_unc,25,[],[],[],[],deltaadjust,scaling);
        [margvalall_adj]=margvaladjust(margvalall_unc,982000,2500); % max observed bid is 979,930 in 12m
        [teststat_adj_alt,teststat_adj_alt_within,test_adj_pairs,teststat_maxmin_adj,samplestat_restr_adj]=restr_test(margvalall_adj,25,[],[],[],[],deltaadjust,scaling);
    else
        [teststat_alt,teststat_alt_within,test_pairs,teststat_maxmin,samplestat_restr]=restr_test(margvalall_unc,10);
        [margvalall_adj]=margvaladjust(margvalall_unc,997000,2500); 
        [teststat_adj_alt,teststat_adj_alt_within,test_adj_pairs,teststat_maxmin_adj,samplestat_restr_adj]=restr_test(margvalall_adj,10);
    end
else
    if size(samplestat_restr,2)<3 % in this case it has been generated before the indicator for "within auction" pairs was added
        if matur==12
            [teststat_alt,teststat_alt_within,test_pairs,teststat_maxmin,samplestat_restr]=restr_test(margvalall_unc,25,[],[],[],[],deltaadjust,scaling);
            [margvalall_adj]=margvaladjust(margvalall_unc,982000,2500); % max observed bid is 979,930 in 12m
            [teststat_adj_alt,teststat_adj_alt_within,test_adj_pairs,teststat_maxmin_adj,samplestat_restr_adj]=restr_test(margvalall_adj,25,[],[],[],[],deltaadjust,scaling);
        else
            [teststat_alt,teststat_alt_within,test_pairs,teststat_maxmin,samplestat_restr]=restr_test(margvalall_unc,10);
            [margvalall_adj]=margvaladjust(margvalall_unc,997000,2500);
            [teststat_adj_alt,teststat_adj_alt_within,test_adj_pairs,teststat_maxmin_adj,samplestat_restr_adj]=restr_test(margvalall_adj,10);
        end
    end
    disp(['Test pairs: ' num2str(size(test_pairs,1))])
    disp(['Test pairs within an auction: ' num2str(sum(test_pairs(:,end)))])
    disp(['Maturity: ' num2str(matur)])
    disp(['p-value of max (diff v)>0: ' num2str(normcdf(teststat_maxmin(1,1)/std(teststat_maxmin(1,:)),0,1))])
    disp(['p-value of min (diff v)<0: ' num2str(1-normcdf(teststat_maxmin(2,1)/std(teststat_maxmin(2,:)),0,1))])
    disp(['p-value of mean (diff v)>0: ' num2str(normcdf(teststat_maxmin(6,1)/std(teststat_maxmin(6,:)),0,1))])
    disp(['p-value of median (diff v)>0: ' num2str(normcdf(teststat_maxmin(5,1)/std(teststat_maxmin(5,:)),0,1))])

    disp(['within auction pairs: p-value of max (diff v)>0: ' num2str(normcdf(teststat_maxmin(3,1)/std(teststat_maxmin(3,:)),0,1))])
    disp(['within auction pairs: p-value of min (diff v)<0: ' num2str(1-normcdf(teststat_maxmin(4,1)/std(teststat_maxmin(4,:)),0,1))])
    disp(['within auction pairs: p-value of mean (diff v)>0: ' num2str(normcdf(teststat_maxmin(8,1)/std(teststat_maxmin(8,:)),0,1))])
    disp(['within auction pairs: p-value of median (diff v)>0: ' num2str(1-normcdf(teststat_maxmin(7,1)/std(teststat_maxmin(7,:)),0,1))])

    disp('Using adjusted marg values: ')
    disp(['p-value of max (diff v)>0: ' num2str(normcdf(teststat_maxmin_adj(1,1)/std(teststat_maxmin_adj(1,:)),0,1))])
    disp(['p-value of min (diff v)<0: ' num2str(1-normcdf(teststat_maxmin_adj(2,1)/std(teststat_maxmin_adj(2,:)),0,1))])
    disp(['p-value of mean (diff v)>0: ' num2str(normcdf(teststat_maxmin_adj(6,1)/std(teststat_maxmin_adj(6,:)),0,1))])
    disp(['p-value of median (diff v)>0: ' num2str(normcdf(teststat_maxmin_adj(5,1)/std(teststat_maxmin_adj(5,:)),0,1))])

    disp(['within auction pairs: p-value of max (diff v)>0: ' num2str(normcdf(teststat_maxmin_adj(3,1)/std(teststat_maxmin_adj(3,:)),0,1))])
    disp(['within auction pairs: p-value of min (diff v)<0: ' num2str(1-normcdf(teststat_maxmin_adj(4,1)/std(teststat_maxmin_adj(4,:)),0,1))])
    disp(['within auction pairs: p-value of mean (diff v)>0: ' num2str(normcdf(teststat_maxmin_adj(8,1)/std(teststat_maxmin_adj(8,:)),0,1))])
    disp(['within auction pairs: p-value of median (diff v)>0: ' num2str(1-normcdf(teststat_maxmin_adj(7,1)/std(teststat_maxmin_adj(7,:)),0,1))])
end

restr_althypo=[matur model aucgroupsize bandw size(test_pairs,1) sum(test_pairs(:,end)) 0 0; ...
    normcdf(teststat_maxmin(1,1)/std(teststat_maxmin(1,:)),0,1) 1-normcdf(teststat_maxmin(2,1)/std(teststat_maxmin(2,:)),0,1) ...
   normcdf(teststat_maxmin(6,1)/std(teststat_maxmin(6,:)),0,1) normcdf(teststat_maxmin(5,1)/std(teststat_maxmin(5,:)),0,1) ...
  normcdf(teststat_maxmin(3,1)/std(teststat_maxmin(3,:)),0,1) 1-normcdf(teststat_maxmin(4,1)/std(teststat_maxmin(4,:)),0,1) ...
  normcdf(teststat_maxmin(8,1)/std(teststat_maxmin(8,:)),0,1) 1-normcdf(teststat_maxmin(7,1)/std(teststat_maxmin(7,:)),0,1); ...
  normcdf(teststat_maxmin_adj(1,1)/std(teststat_maxmin_adj(1,:)),0,1) 1-normcdf(teststat_maxmin_adj(2,1)/std(teststat_maxmin_adj(2,:)),0,1) ...
   normcdf(teststat_maxmin_adj(6,1)/std(teststat_maxmin_adj(6,:)),0,1) normcdf(teststat_maxmin_adj(5,1)/std(teststat_maxmin_adj(5,:)),0,1) ...
  normcdf(teststat_maxmin_adj(3,1)/std(teststat_maxmin_adj(3,:)),0,1) 1-normcdf(teststat_maxmin_adj(4,1)/std(teststat_maxmin_adj(4,:)),0,1) ...
  normcdf(teststat_maxmin_adj(8,1)/std(teststat_maxmin_adj(8,:)),0,1) 1-normcdf(teststat_maxmin_adj(7,1)/std(teststat_maxmin_adj(7,:)),0,1)];
if exist('samplestat','var') && exist('samplestat_restr','var')==0
    restr_samplestat{1,1}=samplestat;
    restr_samplestat{1,2}=samplestat_adj;
else
    restr_samplestat{1,1}=samplestat_restr;
    restr_samplestat{1,2}=samplestat_restr_adj;
end

disp('*****************************************************************************')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Individual hypothesis tests:
if exist('test','var')==0 || exist('samplestat','var')==0
    [test,samplestat,critval]=cvtest_compute(teststat,0.05);
    %Check for NaN entries or Inf and eliminate those before computing
    %aggregates of test statistics and critical values
    b=isfinite(samplestat+critval);
    j=1;
    for i=1:size(critval,1)
        if b(i,1)==1
            critvaladj(j,1)=critval(i,1);
            samplestatadj(j,1)=samplestat(i,1);
            testadj(j,1)=test(i,1);
            j=j+1;
        end
    end
    
    %Evaluate the test statistic at same q and sort
    [testQ,samplestatQ,critvalQ]=cvtest_compute(testsameq,0.05);    
    %Check for NaN entries or Inf and eliminate those before computing
    %aggregates of test statistics and critical values
    b=isfinite(samplestatQ+critvalQ);
    j=1;
    for i=1:size(critvalQ,1)
        if b(i,1)==1
            critvalQadj(j,1)=critvalQ(i,1);
            samplestatQadj(j,1)=samplestatQ(i,1);
            testQadj(j,1)=testQ(i,1);
            j=j+1;
        end
    end
end
disp('MONOTONICITY TEST:')
disp(['Eliminated ' num2str(size(critval,1)-size(critvaladj,1)) ' entries with Inf or NaN'])
disp(['Mean sample stat: ' num2str(mean(samplestatadj))])
disp(['Median sample stat: ' num2str(median(samplestatadj))])
disp(['Mean re-centered crit value: ' num2str(mean(critvaladj))])
disp(['Median re-centered crit value: ' num2str(median(critvaladj))])
teststatall=[testadj samplestatadj critvaladj];
teststatall=sortrows(teststatall,1);
disp(['Monotonicity test rejects for ' num2str(size(find(teststatall(:,1)>0),1)*100/size(teststatall,1)) ' % of bidders'])
disp('EQUALITY TEST:')
disp(['Eliminated ' num2str(size(critvalQ,1)-size(critvalQadj,1)) ' entries with Inf or NaN'])
disp(['Mean sample stat: ' num2str(mean(samplestatQadj))])
disp(['Median sample stat: ' num2str(median(samplestatQadj))])
disp(['Mean re-centered crit value: ' num2str(mean(critvalQadj))])
disp(['Median re-centered crit value: ' num2str(median(critvalQadj))])
teststatallQ=[testQadj samplestatQadj critvalQadj];
teststatallQ=sortrows(teststatallQ,1);
disp(['Equality test (for same q) rejects for ' num2str(size(find(teststatallQ(:,1)>0),1)*100/size(teststatallQ,1)) ' % of bidders'])

%Structure: eliminated mono, mean samplestat, median samplestat, mean crit value, median crit value,  rejects for
%fraction, same for EQ next 6 columns
testindividual=[matur model aucgroupsize bandw zeros(1,8) ; size(critval,1)-size(critvaladj,1) mean(samplestatadj) median(samplestatadj) mean(critvaladj) median(critvaladj) ...
    size(find(teststatall(:,1)>0),1)*100/size(teststatall,1) size(critvalQ,1)-size(critvalQadj,1) mean(samplestatQadj) ...
    median(samplestatQadj) mean(critvalQadj) median(critvalQadj) size(find(teststatallQ(:,1)>0),1)*100/size(teststatallQ,1)];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
disp(['%%%%%%%% VALUE OF INFORMATION %%%%%'])
if matur==12 %trimming values of info above this cutoff due to being unreasonable (cutoff set at 25 bp)
    infocutoff=2500; 
else
    infocutoff=625;
end
disp(['Number of bootstrap observations trimmed: ' num2str(size(valueofinfomax_expost_fu,2)-sum(abs(valueofinfomax_expost_fu)<infocutoff))])
disp(['Out of: ' num2str(size(valueofinfomax_expost_fu,2))])
disp(['Trimmed mean ex post given fixed util: ' num2str(mean(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff & valueofinfomax_expost_fu~=0)))])
disp(['Std Dev in trimmed sample ex post given fixed util: ' num2str(std(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff)))])

if exist('fixutmax_per_t_adj','var')==0
     b=isfinite(fixutmax_per_t);
    j=1;
    for i=1:size(fixutmax_per_t,2)
        if b(1,i)==1
            fixutmax_per_t_adj(j,1)=fixutmax_per_t(1,i);            
            j=j+1;
        end
    end
end

disp(['Trimmed mean expected util: ' num2str(mean(fixutmax_per_t_adj(abs(fixutmax_per_t_adj)<infocutoff & fixutmax_per_t_adj>0)))])

disp(['Share of value of info to mean expected util: ' num2str(mean(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff))...
    /mean(fixutmax_per_t_adj(abs(fixutmax_per_t_adj)<infocutoff)))])

%Structure: # trimmed, out of (observations), mean ex post, std dev ex
%post, mean exp utility (uncoditional), value of info as a share
resultsinfo=[matur model aucgroupsize bandw 0 0; size(valueofinfomax_expost_fu,2)-sum(abs(valueofinfomax_expost_fu)<infocutoff) size(valueofinfomax_expost_fu,2) ...
    mean(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff & valueofinfomax_expost_fu~=0)) ...
    std(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff)) ...
    mean(fixutmax_per_t_adj(abs(fixutmax_per_t_adj)<infocutoff & fixutmax_per_t_adj>0)) ...
    mean(valueofinfomax_expost_fu(abs(valueofinfomax_expost_fu)<infocutoff))/mean(fixutmax_per_t_adj(abs(fixutmax_per_t_adj)<infocutoff))];

disp('-----------------------------------------------------------------------------')
disp('-----------------------------------------------------------------------------')
disp('-----------------------------------------------------------------------------')
%save('tests_1m.mat','equaltest','monottest','foc_stud','sq_stud') 
%save('tests_2m.mat','equaltest','monottest','foc_stud','sq_stud') 
%save('tests_4m.mat','equaltest','monottest','foc_stud','sq_stud') 

%teststatboot(monottest2,0.95,Inf)
%teststatboot(equaltest2,0.95,Inf)
