function [tab1,tab2,tab3]=monte_carlo_final_5(paradigm,drawsreq,fractiontossed,recenter,biascorrection,mcsamples,bootstrapdraws)
if nargin<7
    bootstrapdraws=400;
end
if nargin<6
    mcsamples = 50;
end
if nargin<5
   biascorrection=0;
end
if nargin<4
   recenter=1;
end
if nargin<3
   fractiontossed=0;
end
if nargin<2
    draws=50*5/2;
else
    draws=drawsreq*5/2; %5/2 factor would correct for dropped corner observations
end
if nargin<1
   disp('Enter paradigm: 1: IPV. 2: IIV, 3: CV')
end  

% clear
% %rand('twister', 9182);
% rand('state',87651234)
% paradigm=2;     % which monte carlo to perform: 1 for IPV, 2 for IIV, and 3 for Pure CV
% mcsamples = 5; % number of monte carlo samples
% draws=5/2*100;      % number of signals drawn in each monte carlo sample
% bootstrapdraws=400; % number of bootstrap iterations in each monte carlo sample
% fractiontossed=0; % parameter controlling what fraction of vhats will be discarded due
%                      % to the problem of kernels at the boundary of the
%                      % support - this effects performance of median and mean
%                      % tests!
%                      % I toss one third of this fraction of  vhats on the
%                      % bottom and two thirds on the top
%                      %if 0 no vhats are tossed
% bonferoni=(1-0.05/(2/5*draws*(1-fractiontossed)))*100;   % percentile of the bootstrap distribution to which each critical value in 
%                 % the pointwise test will be compared (we have on avg about
%                 % 2/5 of useful (non-corner) signals from 'draws', hence it should be
%                 % about 0.05/('draws'*'fractiontossed'*2/5): this effects performance of
%                 % ptwise test!
% recenter=1; % 0 if no re-centering and 1 if re-centering of test-statistic distribution
% biascorrection=0; %1 if mean of bootstrap estimates is to be subtracted from the sample value
%               
smoothpar=[];   % 0.061; %smoothing parameter in epanechnikov kernel
bonferoni=(1-0.05/(2/5*draws*(1-fractiontossed)))*100;   % percentile of the bootstrap distribution to which each critical value in 
do_plot=0;      % if at each monte carlo sample we want a plot of vhats

mc_result_med = [];
mc_result_mean = [];
mc_result_ptwise=[];
mc_asympt_med_result = [];
mc_asympt_mean_result = [];
mc_fos_ptwise_result = [];
mc_fos_ptwise_std = [];
mc_ptwise_result = [];
mc_sumsqdiff_ptwise_result = [];
mc_fos_ptwise_stud_result = [];
mc_sumsqdiff_ptwise_stud_result = [];

for mcdraw=1:mcsamples
    % generate data    
    [uninformedbid,informedbid,uninformedbid2,informedbid2,uninformedbid3,informedbid3]=FPA_data2(draws);
      
    % IIV:
    % uninformedbid=7*signals(:,1)/12;
    % informedbid=5*signals(:,1)/16+signals(:,2)/8;                   
    
    % IPV
    % uninformedbid2=5+2*signals(:,1)/3;   
    % informedbid2=5+signals(:,1)/2;  
    
    % Pure CV: from Matthews' paper w/ v~Pareto and s~U[0,v]
        
      
    if mod(mcdraw,25)==0
        disp(['Draw: ' num2str(mcdraw)])
    end
    switch paradigm
        case 2
            bu_v = uninformedbid;
            bi_v = informedbid;
        case 1
            bu_v = uninformedbid2;
            bi_v = informedbid2;
        case 3
            bu_v = uninformedbid3;
            bi_v = informedbid3;
    end

    % use only non-corner solutions for now
    if paradigm==3
        i_noncorner = find(bi_v(:,2)<1 & bu_v(:,2)<1);
    else
        i_noncorner = find(bi_v(:,2)<1);
    end
    bu_eval = bu_v(i_noncorner,1);
    bi_eval = bi_v(i_noncorner,1);
    nbidder=3; 
    cdfbidv_u=[];
    cdfbidv_i=[];
    pdfbidv_u=[];
    pdfbidv_i=[];

% use epanechnikov kernel
% pool all bids together
pdfbidv_u = kernelize(bu_eval,bu_v(:,1),smoothpar,'e');
pdfbidv_i = kernelize(bi_eval,bu_v(:,1),smoothpar,'e');

nbiddata = length(bu_v(:,1));
neval = length(bu_eval);
% cdf estimate is empirical cdf
for j=1:neval
    cdfbidv_u(j) = (1/nbiddata)*sum((bu_v(:,1)<bu_eval(j))); 
    cdfbidv_i(j) = (1/nbiddata)*sum((bu_v(:,1)<bi_eval(j)));
end

% estimate valuations with "uninformed" bids
% for informed bids, condition on having 1 less competitor
vu_eval = bu_eval + (1/(nbidder-1))*cdfbidv_u'./pdfbidv_u;
vi_eval = bi_eval + (1/(nbidder-2))*cdfbidv_i'./pdfbidv_i;

% Try cutting the vhats at the bound of the support
eliminf=isinf(vi_eval)==0;
ptwise_adj=(vi_eval<=prctile(vi_eval(eliminf,1),100*(1-fractiontossed*2/3)) & vi_eval>=prctile(vi_eval(eliminf,1),100*(fractiontossed/3)));
diffptwise = abs(vu_eval(ptwise_adj)-vi_eval(ptwise_adj));
sumsqdiff_ptwise = norm(vu_eval(ptwise_adj)-vi_eval(ptwise_adj))^2;

%first order statistic of the pointwise difference
fos_ptwise=max(abs(vu_eval(ptwise_adj)-vi_eval(ptwise_adj)));

%cut the largest (1-fractiontossed)% of valuations estimates because of kernel problem at the boundary
vu_eval = vu_eval(ptwise_adj); 
vi_eval = vi_eval(ptwise_adj); 

if do_plot==1
    figure(1)
    %plot(sort(vu_eval),sort(vi_eval),'x',vu_eval,vu_eval,'-');
    plot(vu_eval,vi_eval,'x',vu_eval,vu_eval,'-');
    legend('Est. result','45 degree')
    xlabel('Vhat_{3 bidders}')
    ylabel('Vhat_{2 bidders}')
    switch paradigm
        case 2
            title('Interdepent Values example')       
        case 1
            title('Private Values example')
        case 3
            title('Pure Common Values example')
    end
end
% now do the bootstrap
nv = length(bu_v);
diffmed_bs = [];
diffmean_bs = [];
fos_ptwise_bs = [];
diffptwise_bs = [];
sumsqdiff_ptwise_bs = [];
diffptwise_bs_95 = [];
%diffptwise_bs_25 = [];
fos_ptwise_stud_bs = [];
diffptwise_stud_bs = [];
sumsqdiff_ptwise_stud_bs = [];

for bs=1:bootstrapdraws
if bs==1
    vu_eval_bs=[];
    vi_eval_bs=[];
end
    
    % bootstrap index
    bs_ind = unidrnd(nv,nv,1);
    bu_v_bs = bu_v(bs_ind,:);
    bi_v_bs = bi_v(bs_ind,:);
    
    % use only non-corner solutions for now
    i_noncorner_bs = find(bi_v_bs(:,2)<1);

    bu_eval_bs = bu_v_bs(i_noncorner_bs,1);
    bi_eval_bs = bi_v_bs(i_noncorner_bs,1);


    cdfbidv_u_bs=[];
    cdfbidv_i_bs=[];
    pdfbidv_u_bs=[];
    pdfbidv_i_bs=[];
    % use normal kernel estimates with rule of thumb bandwidth
    % pool all bids together and evaluate at ORIGINAL BIDS
    pdfbidv_u_bs = kernelize(bu_eval,bu_v_bs(:,1),smoothpar,'e');
    pdfbidv_i_bs = kernelize(bi_eval,bu_v_bs(:,1),smoothpar,'e');

    nbiddata_u_bs = length(bu_v_bs);
    neval_u_bs = length(bu_eval_bs);
   

    % cdf estimate is empirical cdf
    for j=1:neval
        cdfbidv_u_bs(j) = (1/nbiddata_u_bs)*sum((bu_v_bs(:,1)<bu_eval(j))); 
        cdfbidv_i_bs(j) = (1/nbiddata_u_bs)*sum((bu_v_bs(:,1)<bi_eval(j)));
    end
   
    % estimate valuations with "uninformed" bids at ORIGINAL BIDS
    % for informed bids, condition on having 1 less competitor
    vu_eval_bs(:,bs) = bu_eval + (1/(nbidder-1))*cdfbidv_u_bs'./pdfbidv_u_bs;
    vi_eval_bs(:,bs) = bi_eval + (1/(nbidder-2))*cdfbidv_i_bs'./pdfbidv_i_bs;
    
    
end %bootstrap ends

%estimate the biases:
  bias_u=mean(vu_eval_bs(ptwise_adj),2)-vu_eval;
  bias_i=mean(vi_eval_bs(ptwise_adj),2)-vi_eval;
  
for bs=1:bootstrapdraws
    % calculate test statistics for bs iteration
    if biascorrection==1
      sumsqdiff_ptwise_bs(:,bs) = norm(vu_eval_bs(ptwise_adj,bs)-bias_u-vi_eval_bs(ptwise_adj,bs)-bias_i)^2; 
      diffptwise_bs(:,bs) = abs(vu_eval_bs(ptwise_adj,bs)-bias_u-(vi_eval_bs(ptwise_adj,bs)-bias_i));
      fos_ptwise_bs=[fos_ptwise_bs; max(abs( vu_eval_bs(ptwise_adj,bs)-bias_u-vi_eval_bs(ptwise_adj,bs)+bias_i))];
      % calculate test statistic for bs iteration
      diffmed_bs = [diffmed_bs;median(vu_eval_bs(ptwise_adj,bs)-bias_u)-median(vi_eval_bs(ptwise_adj,bs)-bias_i)];
      diffmean_bs = [diffmean_bs;mean(vu_eval_bs(ptwise_adj,bs)-bias_u)-mean(vi_eval_bs(ptwise_adj,bs)-bias_i)];
    else
      sumsqdiff_ptwise_bs(:,bs) = norm(vu_eval_bs(ptwise_adj,bs)-vu_eval_bs(ptwise_adj,1)-(vi_eval_bs(ptwise_adj,bs)-vi_eval_bs(ptwise_adj,1)))^2;
      diffptwise_bs(:,bs) = abs(vu_eval_bs(ptwise_adj,bs)-vu_eval_bs(ptwise_adj,1)-vi_eval_bs(ptwise_adj,bs)+vi_eval_bs(ptwise_adj,1));
      fos_ptwise_bs=[fos_ptwise_bs; max(abs( vu_eval_bs(ptwise_adj,bs)-vu_eval_bs(ptwise_adj,1)-vi_eval_bs(ptwise_adj,bs)+vi_eval_bs(ptwise_adj,1)))];
      % calculate test statistic for bs iteration
      diffmed_bs = [diffmed_bs;median(vu_eval_bs(ptwise_adj,bs)-vu_eval_bs(ptwise_adj,1))-median(vi_eval_bs(ptwise_adj,bs)-vi_eval_bs(ptwise_adj,1))];
      diffmean_bs = [diffmean_bs;mean(vu_eval_bs(ptwise_adj,bs)-vu_eval_bs(ptwise_adj,1))-mean(vi_eval_bs(ptwise_adj,bs)-vi_eval_bs(ptwise_adj,1))];
    end
end

%construct studentized test statistics:
stdev_hyp=[];
for hyp=1:size(diffptwise_bs,1)
    temp=diffptwise_bs(hyp,:);
    stdev_hyp(hyp,1)=std(temp(isfinite(temp)==1));
end
stder=repmat(stdev_hyp,1,bootstrapdraws);
diffptwise_stud_bs=diffptwise_bs./stder;
% for i=1:size(diffptwise_stud_bs,2)
%     sumsqdiff_ptwise_stud_bs(1,i)=sum(diffptwise_stud_bs(isfinite(diffptwise_stud_bs(:,i)),i).^2);
% end
sumsqdiff_ptwise_stud_bs=sum(diffptwise_stud_bs.^2); %some entries may be NaN in 3rd model (will be trimmed in the "trimming scenario" - ignore without trimming)
for i=1:size(diffptwise_stud_bs,2)
    fos_ptwise_stud_bs(1,i)=max(diffptwise_stud_bs(:,i));
end

if biascorrection==1
    %calculate bias corrected sample statistic:
    diffptwise = abs(vu_eval-bias_u-vi_eval+bias_i);
    fos_ptwise = max(abs(vu_eval-bias_u-vi_eval+bias_i));
    diffmed= median(vu_eval-bias_u)-median(vi_eval-bias_i);
    diffmean= mean(vu_eval-bias_u)-mean(vi_eval-bias_i);
else
    sumsqdiff_ptwise = norm(vu_eval-vi_eval)^2;   
    if max(max(isnan(std(diffptwise_bs,[],2))))==1
        ptwise_std=[];
        for i=1:size(diffptwise_bs,1)
           ptwise_std(i,1)=std(diffptwise_bs(i,isfinite(diffptwise_bs(i,:))));
        end
        sumsqdiff_ptwise_stud=norm((vu_eval-vi_eval)./ptwise_std)^2;
        fos_ptwise_stud=max((abs(vu_eval-vi_eval)./ptwise_std));
    else
        sumsqdiff_ptwise_stud = norm((vu_eval-vi_eval)./std(diffptwise_bs,[],2))^2;
        fos_ptwise_stud=max((abs(vu_eval-vi_eval)./std(diffptwise_bs,[],2)));
    end
    diffptwise = abs(vu_eval-vi_eval);
    fos_ptwise=max(abs(vu_eval-vi_eval));    
    diffmed= median(vu_eval)-median(vi_eval);
    diffmean= mean(vu_eval)-mean(vi_eval);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%% Testing results: %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% asymptotic normal aproximation of CI
diffmed_std=std(diffmed_bs(isnan(diffmed_bs(:,1))==0));
diffmean_std=std(diffmean_bs(isnan(diffmed_bs(:,1))==0));
mc_asympt_med_result=[mc_asympt_med_result; ((diffmed-diffmed_std*norminv(0.975)>0)...
    | (diffmed+diffmed_std*norminv(0.975)<0)) diffmed_std diffmed ];
mc_asympt_mean_result=[mc_asympt_mean_result; ((diffmean-diffmean_std*norminv(0.975)>0)...
    | (diffmean+diffmean_std*norminv(0.975)<0)) diffmean_std diffmean];

% find bootstrap critical value
if recenter==1
    sumsqdiff_ptwise_bs_95 = prctile(sumsqdiff_ptwise_bs(isfinite(sumsqdiff_ptwise_stud_bs)),95); %recentered
    sumsqdiff_ptwise_bs_25 = prctile(sumsqdiff_ptwise_bs(isfinite(sumsqdiff_ptwise_stud_bs)),2.5); %recentered THIS SHOULD BE IGNORED - IT's A ONE SIDED TEST!
    sumsqdiff_ptwise_stud_bs_95 = prctile(sumsqdiff_ptwise_stud_bs(isfinite(sumsqdiff_ptwise_stud_bs)),95); %recentered
    sumsqdiff_ptwise_stud_bs_25 = prctile(sumsqdiff_ptwise_stud_bs(isfinite(sumsqdiff_ptwise_stud_bs)),2.5); %recentered
   
%    fos_ptwise_bs_95 = prctile(fos_ptwise_bs-fos_ptwise,bonferoni); % re-centered
    fos_ptwise_bs_95 = prctile(fos_ptwise_bs,95); % re-centered
    fos_ptwise_bs_25 = prctile(fos_ptwise_bs,2.5); %re-centered
    fos_ptwise_stud_bs_95 = prctile(fos_ptwise_stud_bs(isfinite(fos_ptwise_stud_bs)==1),95);%1-0.05/sum(isfinite(fos_ptwise_bs)==1));%97.5); % re-centered
    fos_ptwise_stud_bs_25 = prctile(fos_ptwise_stud_bs(isfinite(fos_ptwise_stud_bs)==1),2.5); % re-centered
    
    diffmed_bs_975=prctile(diffmed_bs,97.5);%re-centered two-sided
    diffmed_bs_25=prctile(diffmed_bs,2.5); %re-centered
    diffmean_bs_975 = prctile(diffmean_bs,97.5);%re-centered
    diffmean_bs_25 = prctile(diffmean_bs,2.5);%re-centered
else
    fos_ptwise_bs_95 = prctile(fos_ptwise_bs,97.5); %uncentered
    fos_ptwise_bs_25 = prctile(fos_ptwise_bs,2.5); %uncentered
    diffmed_bs_975=prctile(diffmed_bs,97.5); %uncentered
    diffmed_bs_25=prctile(diffmed_bs,2.5); %uncentered
    diffmean_bs_975 = prctile(diffmean_bs,97.5);  %uncentered
    diffmean_bs_25 = prctile(diffmean_bs,2.5);  %uncentered
end

diffptwise_bs_bonf=[];
diffptwise_bs_95=[];
for i=1:size(diffptwise_bs,1)
    if recenter==1
        %diffptwise_bs_95(i,1) = prctile(diffptwise_bs(i,:)-mean(diffptwise(:,1)),bonferoni);  %re-centered CI    
        diffptwise_bs_bonf(i,1) = prctile(diffptwise_bs(i,:),(1-0.05/size(diffptwise_bs,1))*100); %bonferoni);  %re-centered CI    
        diffptwise_bs_95(i,1) = prctile(diffptwise_bs(i,:),95);  %re-centered CI    
    else       
        %diffptwise_bs_95(i,1) = prctile(diffptwise_bs(i,:),bonferoni);      % NOT re-centered    
        diffptwise_bs_bonf(i,1) = prctile(diffptwise_bs(i,:),(1-0.05/size(diffptwise_bs,1))*100); %bonferoni);  %uncentered CI    
        diffptwise_bs_95(i,1) = prctile(diffptwise_bs(i,:),95);  %uncentered CI    
    %diffptwise_bs_25(i,1) = prctile(diffptwise_bs(i,:),2.5)-diffptwise(i,1);      
    end
end

mc_fos_ptwise_std=[mc_fos_ptwise_std; std(diffptwise_bs')'];
if isnan(fos_ptwise_bs_25)==0 && isnan(fos_ptwise_bs_95)==0
    mc_fos_ptwise_result = [mc_fos_ptwise_result; [fos_ptwise_bs_25, fos_ptwise, fos_ptwise_bs_95]];    
end
if isnan(fos_ptwise_stud_bs_25)==0 && isnan(fos_ptwise_stud_bs_95)==0
    mc_fos_ptwise_stud_result = [mc_fos_ptwise_stud_result; [fos_ptwise_stud_bs_25, fos_ptwise_stud, fos_ptwise_stud_bs_95]];    
end

mc_sumsqdiff_ptwise_result = [mc_sumsqdiff_ptwise_result; [sumsqdiff_ptwise_bs_25, sumsqdiff_ptwise, sumsqdiff_ptwise_bs_95]];  
mc_sumsqdiff_ptwise_stud_result = [mc_sumsqdiff_ptwise_stud_result; [sumsqdiff_ptwise_stud_bs_25, sumsqdiff_ptwise_stud, sumsqdiff_ptwise_stud_bs_95]];  

%mc_result_ptwise = [mc_result_ptwise; [diffptwise_bs_25, diffptwise, diffptwise_bs_975]];    
mc_result_med = [mc_result_med; [diffmed_bs_25, diffmed, diffmed_bs_975]];
mc_result_mean = [mc_result_mean; [diffmean_bs_25, diffmean, diffmean_bs_975]];
if isempty(diffptwise)==0
    mc_ptwise_result=[mc_ptwise_result ; [diffptwise_bs_bonf, diffptwise, diffptwise_bs_bonf, diffptwise>diffptwise_bs_bonf]];
    mc_result_ptwise = [mc_result_ptwise; [diffptwise_bs_95, diffptwise, diffptwise_bs_95, diffptwise>diffptwise_bs_95]];    
end


end % finish mcdraw

 switch paradigm
        case 2
           disp(['IIV with trimming: ' num2str(fractiontossed)]);
        case 1
           disp(['IPV with trimming: ' num2str(fractiontossed)]);
        case 3
           disp(['CV with trimming: ' num2str(fractiontossed)]);
 end
disp(['How many data sets? ' num2str(mcdraw)])

disp('How many times rejected?')
%sum((mc_result(:,1)>mc_result(:,2)))
% disp(['Median ' num2str(sum(((mc_result_med(:,1)>0) | (mc_result_med(:,3)<0))))])
% disp(['Mean ' num2str(sum(((mc_result_mean(:,1)>0) | (mc_result_mean(:,3)<0))))])
disp(['Median ' num2str(sum(((mc_result_med(:,1)>mc_result_med(:,2)) | (mc_result_med(:,3)<mc_result_med(:,2))))) ' out of non-NaN: ' num2str(sum(isnan(mc_result_med(:,2))==0))])
disp(['Mean ' num2str(sum(((mc_result_mean(:,1)>mc_result_mean(:,2)) | (mc_result_mean(:,3)<mc_result_mean(:,2))))) ' out of non-NaN: ' num2str(sum(isnan(mc_result_mean(:,2))==0))])

disp('How many times rejected by normal approximation?')
%sum((mc_result(:,1)>mc_result(:,2)))
disp(['Median ' num2str(sum(mc_asympt_med_result(:,1))) ' out of non-NaN: ' num2str(sum(isnan(mc_asympt_med_result(:,2))==0))])

disp(['Mean ' num2str(sum(mc_asympt_mean_result(:,1))) ' out of non-NaN: ' num2str(sum(isnan(mc_asympt_mean_result(:,2))==0))])

%disp(['Pointwise ' num2str(sum(((mc_result_ptwise(:,1)>mc_result_ptwise(:,2)) | (mc_result_ptwise(:,3)<mc_result_ptwise(:,2))))) ...
% ' out of ' num2str(size(mc_result_ptwise,1))])

%disp(['Ratio: ' num2str(sum(((mc_result_ptwise(:,1)>mc_result_ptwise(:,2)) | (mc_result_ptwise(:,3)<mc_result_ptwise(:,2))))/size(mc_result_ptwise,1))])
%sum(((mc_result(:,1)>0) | mc_result(:,3)<0)))

disp('How many times rejected based on bootstrap of FOS: ')

%disp([num2str(sum(((mc_fos_ptwise_result(:,1)>mc_fos_ptwise_result(:,2)) | (mc_fos_ptwise_result(:,3)<mc_fos_ptwise_result(:,2)))))])
if isempty(mc_fos_ptwise_result)==0
    disp([num2str(sum((((mc_fos_ptwise_result(:,3)<mc_fos_ptwise_result(:,2)))))) ' out of non-NaN: ' num2str(sum(isnan(mc_fos_ptwise_result(:,2))==0))])
end

disp(['How many times rejected based on bootstrap of SSQ: '])
disp([num2str(sum((((mc_sumsqdiff_ptwise_result(:,3)<mc_sumsqdiff_ptwise_result(:,2)))))) ' out of non-NaN: ' num2str(sum((mc_sumsqdiff_ptwise_result(:,2))>0))])


% asympt normal for pointwise:
%diffptwise_std=std(diffptwise_bs')';
%diffptwise_std(:,2)=(diffptwise-diffptwise_std*norminv(0.975)>0)...
    %| (diffptwise+diffptwise_std*norminv(0.975)<0);
    
%disp(['Normal approx of ptwise teststat CI rejects: ' num2str(sum(diffptwise_std(:,2)))])

%bootstrap CI ptwise:
%a=[diffptwise_bs_25 diffptwise diffptwise_bs_975 diffptwise>diffptwise_bs_975|diffptwise<diffptwise_bs_25];
disp(['Bootstrap of ptwise teststat CI rejects (0.95): ' num2str(sum(mc_result_ptwise(:,4))) ' out of ' num2str(size(mc_result_ptwise,1))])
disp(['Rejection ratio: ' num2str(sum(mc_result_ptwise(:,4))/size(mc_result_ptwise,1))])

disp(['Bootstrap of ptwise teststat CI rejects (bonferoni): ' num2str(sum(mc_ptwise_result(:,4))) ' out of ' num2str(size(mc_ptwise_result,1))])
disp(['Rejection ratio: ' num2str(sum(mc_ptwise_result(:,4))/size(mc_ptwise_result,1))])

disp('%%%%%%%%%% STUDENTIZED %%%%')
disp('How many times rejected based on boostrap of studentized FOS: ')

%disp([num2str(sum(((mc_fos_ptwise_result(:,1)>mc_fos_ptwise_result(:,2)) | (mc_fos_ptwise_result(:,3)<mc_fos_ptwise_result(:,2)))))])
if isempty(mc_fos_ptwise_stud_result)==0
    disp([num2str(sum((((mc_fos_ptwise_stud_result(:,3)<mc_fos_ptwise_stud_result(:,2)))))) ' out of non-NaN: ' num2str(sum(isnan(mc_fos_ptwise_stud_result(:,2))==0))])
end

disp(['How many times rejected based on boostrap of studentized SSQ: '])
disp([num2str(sum((((mc_sumsqdiff_ptwise_stud_result(:,3)<mc_sumsqdiff_ptwise_stud_result(:,2)))))) ' out of non-NaN: ' num2str(sum((mc_sumsqdiff_ptwise_stud_result(:,2))>0))])


tab1=[sum(((mc_result_med(:,1)>mc_result_med(:,2)) | (mc_result_med(:,3)<mc_result_med(:,2))))/sum(isnan(mc_result_med(:,2))==0) sum((((mc_sumsqdiff_ptwise_result(:,3)<mc_sumsqdiff_ptwise_result(:,2)))))/sum((mc_sumsqdiff_ptwise_result(:,2))>0) ... 
    sum((((mc_fos_ptwise_result(:,3)<mc_fos_ptwise_result(:,2)))))/sum(isnan(mc_fos_ptwise_result(:,2))==0)];
tab2=[sum(mc_result_ptwise(:,4))/size(mc_result_ptwise,1) sum(mc_ptwise_result(:,4))/size(mc_ptwise_result,1)];
tab3=[sum((((mc_sumsqdiff_ptwise_stud_result(:,3)<mc_sumsqdiff_ptwise_stud_result(:,2)))))/sum((mc_sumsqdiff_ptwise_stud_result(:,2))>0) sum((((mc_fos_ptwise_stud_result(:,3)<mc_fos_ptwise_stud_result(:,2)))))/sum(isnan(mc_fos_ptwise_stud_result(:,2))==0)];

